{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "samtools view cram to bam",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "view",
                "-b"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/output.bam"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#cram_to_bam.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#cram_to_bam.cwl/reference"
                }
            ],
            "id": "#cram_to_bam.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.bam"
                    },
                    "id": "#cram_to_bam.cwl/bam"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "cram_to_bam workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl/cram"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl/index_bam/indexed_bam",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#workflow.cwl/bam"
                }
            ],
            "steps": [
                {
                    "run": "#cram_to_bam.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/cram",
                            "id": "#workflow.cwl/cram_to_bam/cram"
                        },
                        {
                            "source": "#workflow.cwl/reference",
                            "id": "#workflow.cwl/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/cram_to_bam/bam"
                    ],
                    "id": "#workflow.cwl/cram_to_bam"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/cram_to_bam/bam",
                            "id": "#workflow.cwl/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/index_bam/indexed_bam"
                    ],
                    "id": "#workflow.cwl/index_bam"
                }
            ],
            "id": "#workflow.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "add bam_readcount info to vcf",
            "baseCommand": [
                "vcf-readcount-annotator"
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.bam_readcount.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#add_bam_readcount_to_vcf.cwl/bam_readcount_tsv"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#add_bam_readcount_to_vcf.cwl/data_type"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#add_bam_readcount_to_vcf.cwl/sample_name"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#add_bam_readcount_to_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.bam_readcount.vcf.gz"
                    },
                    "id": "#add_bam_readcount_to_vcf.cwl/annotated_bam_readcount_vcf"
                }
            ],
            "id": "#add_bam_readcount_to_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "add VEP annotation to report",
            "baseCommand": [
                "/usr/bin/python",
                "/usr/bin/add_annotations_to_table_helper.py"
            ],
            "arguments": [
                {
                    "position": 4,
                    "valueFrom": "$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#add_vep_fields_to_table.cwl/tsv"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#add_vep_fields_to_table.cwl/vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "prefix": "",
                        "itemSeparator": ",",
                        "separate": false,
                        "position": 3
                    },
                    "id": "#add_vep_fields_to_table.cwl/vep_fields"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "variants.annotated.tsv"
                    },
                    "id": "#add_vep_fields_to_table.cwl/annotated_variants_tsv"
                }
            ],
            "id": "#add_vep_fields_to_table.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/opt/htslib/bin/bgzip"
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ],
            "id": "#bgzip.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "CombineVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "CombineVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "-genotypeMergeOptions",
                "PRIORITIZE",
                "--rod_priority_list",
                "mutect,varscan,strelka,pindel,docm",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/combined.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:docm",
                        "position": 6
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_variants.cwl/docm_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:mutect",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_variants.cwl/mutect_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:pindel",
                        "position": 5
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_variants.cwl/pindel_vcf"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#combine_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:strelka",
                        "position": 4
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_variants.cwl/strelka_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:varscan",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_variants.cwl/varscan_vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "combined.vcf.gz"
                    },
                    "id": "#combine_variants.cwl/combined_vcf"
                }
            ],
            "id": "#combine_variants.cwl"
        },
        {
            "class": "Workflow",
            "label": "Detect Variants workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#detect_variants.cwl/annotate_coding_only"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "id": "#detect_variants.cwl/cle_vcf_filter"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#detect_variants.cwl/cosmic_vcf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#detect_variants.cwl/custom_gnomad_vcf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#detect_variants.cwl/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#detect_variants.cwl/docm_vcf"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.001,
                    "id": "#detect_variants.cwl/filter_gnomADe_maximum_population_allele_frequency"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.15,
                    "id": "#detect_variants.cwl/filter_mapq0_threshold"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#detect_variants.cwl/hgvs_annotation"
                },
                {
                    "type": "File",
                    "id": "#detect_variants.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#detect_variants.cwl/mutect_artifact_detection_mode"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#detect_variants.cwl/mutect_max_alt_allele_in_normal_fraction"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#detect_variants.cwl/mutect_max_alt_alleles_in_normal_count"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#detect_variants.cwl/mutect_scatter_count"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#detect_variants.cwl/normal_cram"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#detect_variants.cwl/panel_of_normals_vcf"
                },
                {
                    "type": "int",
                    "default": 400,
                    "id": "#detect_variants.cwl/pindel_insert_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#detect_variants.cwl/readcount_minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#detect_variants.cwl/readcount_minimum_mapping_quality"
                },
                {
                    "type": "string",
                    "id": "#detect_variants.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#detect_variants.cwl/strelka_cpu_reserved"
                },
                {
                    "type": "boolean",
                    "id": "#detect_variants.cwl/strelka_exome_mode"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#detect_variants.cwl/synonyms_file"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#detect_variants.cwl/tumor_cram"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "CHROM",
                        "POS",
                        "ID",
                        "REF",
                        "ALT",
                        "set",
                        "AC",
                        "AF"
                    ],
                    "id": "#detect_variants.cwl/variants_to_table_fields"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "GT",
                        "AD"
                    ],
                    "id": "#detect_variants.cwl/variants_to_table_genotype_fields"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#detect_variants.cwl/varscan_max_normal_freq"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#detect_variants.cwl/varscan_min_coverage"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "id": "#detect_variants.cwl/varscan_min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "id": "#detect_variants.cwl/varscan_p_value"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "id": "#detect_variants.cwl/varscan_strand_filter"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#detect_variants.cwl/vep_cache_dir"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "HGVSc",
                        "HGVSp"
                    ],
                    "id": "#detect_variants.cwl/vep_to_table_fields"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#detect_variants.cwl/docm/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#detect_variants.cwl/docm_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#detect_variants.cwl/docm/unfiltered_vcf",
                    "id": "#detect_variants.cwl/docm_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#detect_variants.cwl/annotated_filter_index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#detect_variants.cwl/final_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#detect_variants.cwl/add_vep_fields_to_table/annotated_variants_tsv",
                    "id": "#detect_variants.cwl/final_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#detect_variants.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#detect_variants.cwl/final_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#detect_variants.cwl/mutect/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#detect_variants.cwl/mutect_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#detect_variants.cwl/mutect/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#detect_variants.cwl/mutect_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#detect_variants.cwl/normal_bam_readcount/bam_readcount_tsv",
                    "id": "#detect_variants.cwl/normal_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#detect_variants.cwl/pindel/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#detect_variants.cwl/pindel_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#detect_variants.cwl/pindel/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#detect_variants.cwl/pindel_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#detect_variants.cwl/strelka/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#detect_variants.cwl/strelka_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#detect_variants.cwl/strelka/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#detect_variants.cwl/strelka_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#detect_variants.cwl/tumor_bam_readcount/bam_readcount_tsv",
                    "id": "#detect_variants.cwl/tumor_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#detect_variants.cwl/varscan/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#detect_variants.cwl/varscan_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#detect_variants.cwl/varscan/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#detect_variants.cwl/varscan_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#detect_variants.cwl/annotate_variants/vep_summary",
                    "id": "#detect_variants.cwl/vep_summary"
                }
            ],
            "steps": [
                {
                    "run": "#add_bam_readcount_to_vcf.cwl",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/normal_bam_readcount/bam_readcount_tsv",
                            "id": "#detect_variants.cwl/add_normal_bam_readcount_to_vcf/bam_readcount_tsv"
                        },
                        {
                            "default": "DNA",
                            "id": "#detect_variants.cwl/add_normal_bam_readcount_to_vcf/data_type"
                        },
                        {
                            "default": "NORMAL",
                            "id": "#detect_variants.cwl/add_normal_bam_readcount_to_vcf/sample_name"
                        },
                        {
                            "source": "#detect_variants.cwl/add_tumor_bam_readcount_to_vcf/annotated_bam_readcount_vcf",
                            "id": "#detect_variants.cwl/add_normal_bam_readcount_to_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/add_normal_bam_readcount_to_vcf/annotated_bam_readcount_vcf"
                    ],
                    "id": "#detect_variants.cwl/add_normal_bam_readcount_to_vcf"
                },
                {
                    "run": "#add_bam_readcount_to_vcf.cwl",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/tumor_bam_readcount/bam_readcount_tsv",
                            "id": "#detect_variants.cwl/add_tumor_bam_readcount_to_vcf/bam_readcount_tsv"
                        },
                        {
                            "default": "DNA",
                            "id": "#detect_variants.cwl/add_tumor_bam_readcount_to_vcf/data_type"
                        },
                        {
                            "default": "TUMOR",
                            "id": "#detect_variants.cwl/add_tumor_bam_readcount_to_vcf/sample_name"
                        },
                        {
                            "source": "#detect_variants.cwl/annotate_variants/annotated_vcf",
                            "id": "#detect_variants.cwl/add_tumor_bam_readcount_to_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/add_tumor_bam_readcount_to_vcf/annotated_bam_readcount_vcf"
                    ],
                    "id": "#detect_variants.cwl/add_tumor_bam_readcount_to_vcf"
                },
                {
                    "run": "#add_vep_fields_to_table.cwl",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/variants_to_table/variants_tsv",
                            "id": "#detect_variants.cwl/add_vep_fields_to_table/tsv"
                        },
                        {
                            "source": "#detect_variants.cwl/annotated_filter_index/indexed_vcf",
                            "id": "#detect_variants.cwl/add_vep_fields_to_table/vcf"
                        },
                        {
                            "source": "#detect_variants.cwl/vep_to_table_fields",
                            "id": "#detect_variants.cwl/add_vep_fields_to_table/vep_fields"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/add_vep_fields_to_table/annotated_variants_tsv"
                    ],
                    "id": "#detect_variants.cwl/add_vep_fields_to_table"
                },
                {
                    "run": "#vep.cwl",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/vep_cache_dir",
                            "id": "#detect_variants.cwl/annotate_variants/cache_dir"
                        },
                        {
                            "source": "#detect_variants.cwl/annotate_coding_only",
                            "id": "#detect_variants.cwl/annotate_variants/coding_only"
                        },
                        {
                            "source": "#detect_variants.cwl/custom_gnomad_vcf",
                            "id": "#detect_variants.cwl/annotate_variants/custom_gnomad_vcf"
                        },
                        {
                            "source": "#detect_variants.cwl/hgvs_annotation",
                            "id": "#detect_variants.cwl/annotate_variants/hgvs"
                        },
                        {
                            "source": "#detect_variants.cwl/reference",
                            "id": "#detect_variants.cwl/annotate_variants/reference"
                        },
                        {
                            "source": "#detect_variants.cwl/synonyms_file",
                            "id": "#detect_variants.cwl/annotate_variants/synonyms_file"
                        },
                        {
                            "source": "#detect_variants.cwl/combine/combined_vcf",
                            "id": "#detect_variants.cwl/annotate_variants/vcf"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/annotate_variants/annotated_vcf",
                        "#detect_variants.cwl/annotate_variants/vep_summary"
                    ],
                    "id": "#detect_variants.cwl/annotate_variants"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/filter_vcf/filtered_vcf",
                            "id": "#detect_variants.cwl/annotated_filter_bgzip/file"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/annotated_filter_bgzip/bgzipped_file"
                    ],
                    "id": "#detect_variants.cwl/annotated_filter_bgzip"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/annotated_filter_bgzip/bgzipped_file",
                            "id": "#detect_variants.cwl/annotated_filter_index/vcf"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/annotated_filter_index/indexed_vcf"
                    ],
                    "id": "#detect_variants.cwl/annotated_filter_index"
                },
                {
                    "run": "#combine_variants.cwl",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/docm/filtered_vcf",
                            "id": "#detect_variants.cwl/combine/docm_vcf"
                        },
                        {
                            "source": "#detect_variants.cwl/mutect/filtered_vcf",
                            "id": "#detect_variants.cwl/combine/mutect_vcf"
                        },
                        {
                            "source": "#detect_variants.cwl/pindel/filtered_vcf",
                            "id": "#detect_variants.cwl/combine/pindel_vcf"
                        },
                        {
                            "source": "#detect_variants.cwl/reference",
                            "id": "#detect_variants.cwl/combine/reference"
                        },
                        {
                            "source": "#detect_variants.cwl/strelka/filtered_vcf",
                            "id": "#detect_variants.cwl/combine/strelka_vcf"
                        },
                        {
                            "source": "#detect_variants.cwl/varscan/filtered_vcf",
                            "id": "#detect_variants.cwl/combine/varscan_vcf"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/combine/combined_vcf"
                    ],
                    "id": "#detect_variants.cwl/combine"
                },
                {
                    "run": "#workflow.cwl_2",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/docm_vcf",
                            "id": "#detect_variants.cwl/docm/docm_vcf"
                        },
                        {
                            "source": "#detect_variants.cwl/interval_list",
                            "id": "#detect_variants.cwl/docm/interval_list"
                        },
                        {
                            "source": "#detect_variants.cwl/normal_cram",
                            "id": "#detect_variants.cwl/docm/normal_cram"
                        },
                        {
                            "source": "#detect_variants.cwl/reference",
                            "id": "#detect_variants.cwl/docm/reference"
                        },
                        {
                            "source": "#detect_variants.cwl/tumor_cram",
                            "id": "#detect_variants.cwl/docm/tumor_cram"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/docm/unfiltered_vcf",
                        "#detect_variants.cwl/docm/filtered_vcf"
                    ],
                    "id": "#detect_variants.cwl/docm"
                },
                {
                    "run": "#filter_vcf.cwl",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/cle_vcf_filter",
                            "id": "#detect_variants.cwl/filter_vcf/do_cle_vcf_filter"
                        },
                        {
                            "source": "#detect_variants.cwl/filter_gnomADe_maximum_population_allele_frequency",
                            "id": "#detect_variants.cwl/filter_vcf/filter_gnomADe_maximum_population_allele_frequency"
                        },
                        {
                            "source": "#detect_variants.cwl/filter_mapq0_threshold",
                            "id": "#detect_variants.cwl/filter_vcf/filter_mapq0_threshold"
                        },
                        {
                            "source": "#detect_variants.cwl/reference",
                            "id": "#detect_variants.cwl/filter_vcf/reference"
                        },
                        {
                            "source": "#detect_variants.cwl/tumor_cram_to_bam/bam",
                            "id": "#detect_variants.cwl/filter_vcf/tumor_bam"
                        },
                        {
                            "source": "#detect_variants.cwl/index/indexed_vcf",
                            "id": "#detect_variants.cwl/filter_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/filter_vcf/filtered_vcf"
                    ],
                    "id": "#detect_variants.cwl/filter_vcf"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/add_normal_bam_readcount_to_vcf/annotated_bam_readcount_vcf",
                            "id": "#detect_variants.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/index/indexed_vcf"
                    ],
                    "id": "#detect_variants.cwl/index"
                },
                {
                    "run": "#workflow.cwl_4",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/mutect_artifact_detection_mode",
                            "id": "#detect_variants.cwl/mutect/artifact_detection_mode"
                        },
                        {
                            "source": "#detect_variants.cwl/cosmic_vcf",
                            "id": "#detect_variants.cwl/mutect/cosmic_vcf"
                        },
                        {
                            "source": "#detect_variants.cwl/dbsnp_vcf",
                            "id": "#detect_variants.cwl/mutect/dbsnp_vcf"
                        },
                        {
                            "source": "#detect_variants.cwl/interval_list",
                            "id": "#detect_variants.cwl/mutect/interval_list"
                        },
                        {
                            "source": "#detect_variants.cwl/mutect_max_alt_allele_in_normal_fraction",
                            "id": "#detect_variants.cwl/mutect/max_alt_allele_in_normal_fraction"
                        },
                        {
                            "source": "#detect_variants.cwl/mutect_max_alt_alleles_in_normal_count",
                            "id": "#detect_variants.cwl/mutect/max_alt_alleles_in_normal_count"
                        },
                        {
                            "source": "#detect_variants.cwl/normal_cram",
                            "id": "#detect_variants.cwl/mutect/normal_cram"
                        },
                        {
                            "source": "#detect_variants.cwl/panel_of_normals_vcf",
                            "id": "#detect_variants.cwl/mutect/panel_of_normals_vcf"
                        },
                        {
                            "source": "#detect_variants.cwl/reference",
                            "id": "#detect_variants.cwl/mutect/reference"
                        },
                        {
                            "source": "#detect_variants.cwl/mutect_scatter_count",
                            "id": "#detect_variants.cwl/mutect/scatter_count"
                        },
                        {
                            "source": "#detect_variants.cwl/tumor_cram",
                            "id": "#detect_variants.cwl/mutect/tumor_cram"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/mutect/unfiltered_vcf",
                        "#detect_variants.cwl/mutect/filtered_vcf"
                    ],
                    "id": "#detect_variants.cwl/mutect"
                },
                {
                    "run": "#bam_readcount.cwl",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/normal_cram_to_bam/bam",
                            "id": "#detect_variants.cwl/normal_bam_readcount/bam"
                        },
                        {
                            "source": "#detect_variants.cwl/readcount_minimum_base_quality",
                            "id": "#detect_variants.cwl/normal_bam_readcount/min_base_quality"
                        },
                        {
                            "source": "#detect_variants.cwl/readcount_minimum_mapping_quality",
                            "id": "#detect_variants.cwl/normal_bam_readcount/min_mapping_quality"
                        },
                        {
                            "source": "#detect_variants.cwl/reference",
                            "id": "#detect_variants.cwl/normal_bam_readcount/reference_fasta"
                        },
                        {
                            "default": "NORMAL",
                            "id": "#detect_variants.cwl/normal_bam_readcount/sample"
                        },
                        {
                            "source": "#detect_variants.cwl/combine/combined_vcf",
                            "id": "#detect_variants.cwl/normal_bam_readcount/vcf"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/normal_bam_readcount/bam_readcount_tsv"
                    ],
                    "id": "#detect_variants.cwl/normal_bam_readcount"
                },
                {
                    "run": "#workflow.cwl",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/normal_cram",
                            "id": "#detect_variants.cwl/normal_cram_to_bam/cram"
                        },
                        {
                            "source": "#detect_variants.cwl/reference",
                            "id": "#detect_variants.cwl/normal_cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/normal_cram_to_bam/bam"
                    ],
                    "id": "#detect_variants.cwl/normal_cram_to_bam"
                },
                {
                    "run": "#workflow.cwl_5",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/pindel_insert_size",
                            "id": "#detect_variants.cwl/pindel/insert_size"
                        },
                        {
                            "source": "#detect_variants.cwl/interval_list",
                            "id": "#detect_variants.cwl/pindel/interval_list"
                        },
                        {
                            "source": "#detect_variants.cwl/normal_cram",
                            "id": "#detect_variants.cwl/pindel/normal_cram"
                        },
                        {
                            "source": "#detect_variants.cwl/reference",
                            "id": "#detect_variants.cwl/pindel/reference"
                        },
                        {
                            "source": "#detect_variants.cwl/tumor_cram",
                            "id": "#detect_variants.cwl/pindel/tumor_cram"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/pindel/unfiltered_vcf",
                        "#detect_variants.cwl/pindel/filtered_vcf"
                    ],
                    "id": "#detect_variants.cwl/pindel"
                },
                {
                    "run": "#workflow.cwl_6",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/strelka_cpu_reserved",
                            "id": "#detect_variants.cwl/strelka/cpu_reserved"
                        },
                        {
                            "source": "#detect_variants.cwl/strelka_exome_mode",
                            "id": "#detect_variants.cwl/strelka/exome_mode"
                        },
                        {
                            "source": "#detect_variants.cwl/interval_list",
                            "id": "#detect_variants.cwl/strelka/interval_list"
                        },
                        {
                            "source": "#detect_variants.cwl/normal_cram",
                            "id": "#detect_variants.cwl/strelka/normal_cram"
                        },
                        {
                            "source": "#detect_variants.cwl/reference",
                            "id": "#detect_variants.cwl/strelka/reference"
                        },
                        {
                            "source": "#detect_variants.cwl/tumor_cram",
                            "id": "#detect_variants.cwl/strelka/tumor_cram"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/strelka/unfiltered_vcf",
                        "#detect_variants.cwl/strelka/filtered_vcf"
                    ],
                    "id": "#detect_variants.cwl/strelka"
                },
                {
                    "run": "#bam_readcount.cwl",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/tumor_cram_to_bam/bam",
                            "id": "#detect_variants.cwl/tumor_bam_readcount/bam"
                        },
                        {
                            "source": "#detect_variants.cwl/readcount_minimum_base_quality",
                            "id": "#detect_variants.cwl/tumor_bam_readcount/min_base_quality"
                        },
                        {
                            "source": "#detect_variants.cwl/readcount_minimum_mapping_quality",
                            "id": "#detect_variants.cwl/tumor_bam_readcount/min_mapping_quality"
                        },
                        {
                            "source": "#detect_variants.cwl/reference",
                            "id": "#detect_variants.cwl/tumor_bam_readcount/reference_fasta"
                        },
                        {
                            "default": "TUMOR",
                            "id": "#detect_variants.cwl/tumor_bam_readcount/sample"
                        },
                        {
                            "source": "#detect_variants.cwl/combine/combined_vcf",
                            "id": "#detect_variants.cwl/tumor_bam_readcount/vcf"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/tumor_bam_readcount/bam_readcount_tsv"
                    ],
                    "id": "#detect_variants.cwl/tumor_bam_readcount"
                },
                {
                    "run": "#workflow.cwl",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/tumor_cram",
                            "id": "#detect_variants.cwl/tumor_cram_to_bam/cram"
                        },
                        {
                            "source": "#detect_variants.cwl/reference",
                            "id": "#detect_variants.cwl/tumor_cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/tumor_cram_to_bam/bam"
                    ],
                    "id": "#detect_variants.cwl/tumor_cram_to_bam"
                },
                {
                    "run": "#variants_to_table.cwl",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/variants_to_table_fields",
                            "id": "#detect_variants.cwl/variants_to_table/fields"
                        },
                        {
                            "source": "#detect_variants.cwl/variants_to_table_genotype_fields",
                            "id": "#detect_variants.cwl/variants_to_table/genotype_fields"
                        },
                        {
                            "source": "#detect_variants.cwl/reference",
                            "id": "#detect_variants.cwl/variants_to_table/reference"
                        },
                        {
                            "source": "#detect_variants.cwl/annotated_filter_index/indexed_vcf",
                            "id": "#detect_variants.cwl/variants_to_table/vcf"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/variants_to_table/variants_tsv"
                    ],
                    "id": "#detect_variants.cwl/variants_to_table"
                },
                {
                    "run": "#workflow.cwl_8",
                    "in": [
                        {
                            "source": "#detect_variants.cwl/interval_list",
                            "id": "#detect_variants.cwl/varscan/interval_list"
                        },
                        {
                            "source": "#detect_variants.cwl/varscan_max_normal_freq",
                            "id": "#detect_variants.cwl/varscan/max_normal_freq"
                        },
                        {
                            "source": "#detect_variants.cwl/varscan_min_coverage",
                            "id": "#detect_variants.cwl/varscan/min_coverage"
                        },
                        {
                            "source": "#detect_variants.cwl/varscan_min_var_freq",
                            "id": "#detect_variants.cwl/varscan/min_var_freq"
                        },
                        {
                            "source": "#detect_variants.cwl/normal_cram",
                            "id": "#detect_variants.cwl/varscan/normal_cram"
                        },
                        {
                            "source": "#detect_variants.cwl/varscan_p_value",
                            "id": "#detect_variants.cwl/varscan/p_value"
                        },
                        {
                            "source": "#detect_variants.cwl/reference",
                            "id": "#detect_variants.cwl/varscan/reference"
                        },
                        {
                            "source": "#detect_variants.cwl/varscan_strand_filter",
                            "id": "#detect_variants.cwl/varscan/strand_filter"
                        },
                        {
                            "source": "#detect_variants.cwl/tumor_cram",
                            "id": "#detect_variants.cwl/varscan/tumor_cram"
                        }
                    ],
                    "out": [
                        "#detect_variants.cwl/varscan/unfiltered_vcf",
                        "#detect_variants.cwl/varscan/filtered_vcf"
                    ],
                    "id": "#detect_variants.cwl/varscan"
                }
            ],
            "id": "#detect_variants.cwl"
        },
        {
            "class": "Workflow",
            "label": "Apply filters to VCF file",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "id": "#filter_vcf.cwl/do_cle_vcf_filter"
                },
                {
                    "type": "float",
                    "id": "#filter_vcf.cwl/filter_gnomADe_maximum_population_allele_frequency"
                },
                {
                    "type": "float",
                    "id": "#filter_vcf.cwl/filter_mapq0_threshold"
                },
                {
                    "type": "string",
                    "id": "#filter_vcf.cwl/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#filter_vcf.cwl/tumor_bam"
                },
                {
                    "type": "File",
                    "id": "#filter_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#filter_vcf.cwl/filter_vcf_cle/cle_filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#filter_vcf.cwl/filtered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#filter_vcf_cle.cwl",
                    "in": [
                        {
                            "source": "#filter_vcf.cwl/do_cle_vcf_filter",
                            "id": "#filter_vcf.cwl/filter_vcf_cle/filter"
                        },
                        {
                            "source": "#filter_vcf.cwl/filter_vcf_mapq0/mapq0_filtered_vcf",
                            "id": "#filter_vcf.cwl/filter_vcf_cle/vcf"
                        }
                    ],
                    "out": [
                        "#filter_vcf.cwl/filter_vcf_cle/cle_filtered_vcf"
                    ],
                    "id": "#filter_vcf.cwl/filter_vcf_cle"
                },
                {
                    "run": "#filter_vcf_gnomADe_allele_freq.cwl",
                    "in": [
                        {
                            "source": "#filter_vcf.cwl/filter_gnomADe_maximum_population_allele_frequency",
                            "id": "#filter_vcf.cwl/filter_vcf_gnomADe_allele_freq/maximum_population_allele_frequency"
                        },
                        {
                            "source": "#filter_vcf.cwl/vcf",
                            "id": "#filter_vcf.cwl/filter_vcf_gnomADe_allele_freq/vcf"
                        }
                    ],
                    "out": [
                        "#filter_vcf.cwl/filter_vcf_gnomADe_allele_freq/filtered_vcf"
                    ],
                    "id": "#filter_vcf.cwl/filter_vcf_gnomADe_allele_freq"
                },
                {
                    "run": "#filter_vcf_mapq0.cwl",
                    "in": [
                        {
                            "source": "#filter_vcf.cwl/reference",
                            "id": "#filter_vcf.cwl/filter_vcf_mapq0/reference"
                        },
                        {
                            "source": "#filter_vcf.cwl/filter_mapq0_threshold",
                            "id": "#filter_vcf.cwl/filter_vcf_mapq0/threshold"
                        },
                        {
                            "source": "#filter_vcf.cwl/tumor_bam",
                            "id": "#filter_vcf.cwl/filter_vcf_mapq0/tumor_bam"
                        },
                        {
                            "source": "#filter_vcf.cwl/filter_vcf_gnomADe_allele_freq/filtered_vcf",
                            "id": "#filter_vcf.cwl/filter_vcf_mapq0/vcf"
                        }
                    ],
                    "out": [
                        "#filter_vcf.cwl/filter_vcf_mapq0/mapq0_filtered_vcf"
                    ],
                    "id": "#filter_vcf.cwl/filter_vcf_mapq0"
                }
            ],
            "id": "#filter_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "cle_annotated_vcf_filter",
            "arguments": [
                "/usr/bin/perl",
                "/usr/bin/docm_and_coding_indel_selection.pl",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)"
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "filter",
                        "position": 1
                    },
                    "id": "#filter_vcf_cle.cwl/filter"
                },
                {
                    "type": "File",
                    "id": "#filter_vcf_cle.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated_filtered.vcf"
                    },
                    "id": "#filter_vcf_cle.cwl/cle_filtered_vcf"
                }
            ],
            "id": "#filter_vcf_cle.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "gnomADe_AF filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/vcf_check.pl"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.vcf.path)"
                },
                {
                    "valueFrom": "$(runtime.outdir)/annotated.af_filtered.vcf"
                },
                "/usr/bin/perl",
                "/opt/vep/ensembl-vep/filter_vep",
                "--format",
                "vcf",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.af_filtered.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "float",
                    "inputBinding": {
                        "valueFrom": "${\n    return [\n        \"--filter\",\n        [\n            \"gnomADe_AF\", \"<\", inputs.maximum_population_allele_frequency,\n            \"or not\", \"gnomADe_AF\"\n        ].join(\" \")\n    ]\n}\n",
                        "position": 2
                    },
                    "id": "#filter_vcf_gnomADe_allele_freq.cwl/maximum_population_allele_frequency"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#filter_vcf_gnomADe_allele_freq.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.af_filtered.vcf"
                    },
                    "id": "#filter_vcf_gnomADe_allele_freq.cwl/filtered_vcf"
                }
            ],
            "id": "#filter_vcf_gnomADe_allele_freq.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "filter_vcf for variants with high percentage of mapq0 reads",
            "arguments": [
                "/bin/bash",
                "/usr/bin/mapq0_vcf_filter.sh",
                {
                    "valueFrom": "$(runtime.outdir)/mapq_filtered.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#filter_vcf_mapq0.cwl/reference"
                },
                {
                    "type": "float",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#filter_vcf_mapq0.cwl/threshold"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#filter_vcf_mapq0.cwl/tumor_bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#filter_vcf_mapq0.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mapq_filtered.vcf.gz"
                    },
                    "id": "#filter_vcf_mapq0.cwl/mapq0_filtered_vcf"
                }
            ],
            "id": "#filter_vcf_mapq0.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "cp",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/opt/samtools/bin/samtools",
                "index",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index_vcf.cwl/indexed_vcf"
                }
            ],
            "id": "#index_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf merge",
            "baseCommand": [
                "/opt/bcftools/bin/bcftools",
                "concat"
            ],
            "arguments": [
                "--allow-overlaps",
                "--remove-duplicates",
                "--output-type",
                "z",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.merged_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "merged",
                    "id": "#merge.cwl/merged_vcf_basename"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#merge.cwl/vcfs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.merged_vcf_basename).vcf.gz"
                    },
                    "id": "#merge.cwl/merged_vcf"
                }
            ],
            "id": "#merge.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "SelectVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--excludeFiltered",
                        "position": 4
                    },
                    "id": "#select_variants.cwl/exclude_filtered"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 3
                    },
                    "id": "#select_variants.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "select_variants",
                    "id": "#select_variants.cwl/output_vcf_basename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#select_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#select_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf.gz"
                    },
                    "id": "#select_variants.cwl/filtered_vcf"
                }
            ],
            "id": "#select_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/split_interval_list_helper.pl"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000
                }
            ],
            "arguments": [
                {
                    "valueFrom": "OUTPUT=$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT=",
                        "separate": false,
                        "position": 1
                    },
                    "id": "#split_interval_list.cwl/interval_list"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "SCATTER_COUNT=",
                        "separate": false,
                        "position": 2
                    },
                    "id": "#split_interval_list.cwl/scatter_count"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.interval_list"
                    },
                    "id": "#split_interval_list.cwl/split_interval_lists"
                }
            ],
            "id": "#split_interval_list.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "VariantsToTable"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/variants.tsv"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-F"
                        }
                    },
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#variants_to_table.cwl/fields"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-GF"
                        }
                    },
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#variants_to_table.cwl/genotype_fields"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#variants_to_table.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#variants_to_table.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "variants.tsv"
                    },
                    "id": "#variants_to_table.cwl/variants_tsv"
                }
            ],
            "id": "#variants_to_table.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Ensembl Variant Effect Predictor",
            "baseCommand": [
                "/usr/bin/perl",
                "-I",
                "/opt/lib/perl/VEP/Plugins",
                "/usr/bin/variant_effect_predictor.pl"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 32000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "--format",
                "vcf",
                "--vcf",
                "--plugin",
                "Downstream",
                "--plugin",
                "Wildtype",
                "--symbol",
                "--term",
                "SO",
                "--flag_pick",
                "--transcript_version",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.vcf"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.cache_dir) {\n        return [\"--offline\", \"--cache\", \"--dir\", inputs.cache_dir ]\n    }\n    else {\n        return \"--database\"\n    }\n}\n",
                        "position": 4
                    },
                    "id": "#vep.cwl/cache_dir"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--coding_only",
                        "position": 3
                    },
                    "default": false,
                    "id": "#vep.cwl/coding_only"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.custom_gnomad_vcf) {\n        return ['--check_existing', '--custom', inputs.custom_gnomad_vcf.path + ',gnomADe,vcf,exact,0,AF,AF_AFR,AF_AMR,AF_ASJ,AF_EAS,AF_FIN,AF_NFE,AF_OTH,AF_SAS']\n    }\n    else {\n        if (inputs.cache_dir) {\n            return ['--max_af', '--af_gnomad', '--af_1kg']\n        }\n        else {\n            return []\n        }\n    }\n}\n",
                        "position": 6
                    },
                    "id": "#vep.cwl/custom_gnomad_vcf"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.hgvs) {\n        if (inputs.cache_dir) {\n            return [\"--hgvs\", \"--fasta\", inputs.reference]\n        }\n        else {\n            return [\"--hgvs\"]\n        }\n    }\n    else {\n        return []\n    }\n}\n",
                        "position": 5
                    },
                    "id": "#vep.cwl/hgvs"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#vep.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--synonyms",
                        "position": 2
                    },
                    "id": "#vep.cwl/synonyms_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#vep.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.vcf"
                    },
                    "id": "#vep.cwl/annotated_vcf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.vcf_summary.html"
                    },
                    "id": "#vep.cwl/vep_summary"
                }
            ],
            "id": "#vep.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "HaplotypeCaller (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "HaplotypeCaller"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "arguments": [
                "-gt_mode",
                "GENOTYPE_GIVEN_ALLELES",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/docm_out.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--alleles",
                        "position": 4
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#GATK_haplotype_caller.cwl/docm_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 5
                    },
                    "id": "#GATK_haplotype_caller.cwl/interval_list"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#GATK_haplotype_caller.cwl/normal_cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#GATK_haplotype_caller.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 3
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#GATK_haplotype_caller.cwl/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "docm_out.vcf"
                    },
                    "id": "#GATK_haplotype_caller.cwl/docm_out"
                }
            ],
            "id": "#GATK_haplotype_caller.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "docm filter",
            "arguments": [
                "/usr/bin/perl",
                "/usr/bin/docm_filter.pl",
                "$(inputs.docm_out.path)",
                "$(inputs.normal_cram.path)",
                "$(inputs.tumor_cram.path)",
                "$(runtime.outdir)"
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#docm_filter.cwl/docm_out"
                },
                {
                    "type": "File",
                    "id": "#docm_filter.cwl/normal_cram"
                },
                {
                    "type": "File",
                    "id": "#docm_filter.cwl/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "docm_filter_out.vcf"
                    },
                    "id": "#docm_filter.cwl/docm_filter_out"
                }
            ],
            "id": "#docm_filter.cwl"
        },
        {
            "class": "Workflow",
            "label": "Detect Docm variants",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/docm_vcf"
                },
                {
                    "type": "File",
                    "id": "#workflow.cwl_2/interval_list"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_2/normal_cram"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_2/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_2/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_2/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_2/GATK_haplotype_caller/docm_out",
                    "id": "#workflow.cwl_2/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#GATK_haplotype_caller.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/docm_vcf",
                            "id": "#workflow.cwl_2/GATK_haplotype_caller/docm_vcf"
                        },
                        {
                            "source": "#workflow.cwl_2/interval_list",
                            "id": "#workflow.cwl_2/GATK_haplotype_caller/interval_list"
                        },
                        {
                            "source": "#workflow.cwl_2/normal_cram",
                            "id": "#workflow.cwl_2/GATK_haplotype_caller/normal_cram"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/GATK_haplotype_caller/reference"
                        },
                        {
                            "source": "#workflow.cwl_2/tumor_cram",
                            "id": "#workflow.cwl_2/GATK_haplotype_caller/tumor_cram"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/GATK_haplotype_caller/docm_out"
                    ],
                    "id": "#workflow.cwl_2/GATK_haplotype_caller"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/docm_filter/docm_filter_out",
                            "id": "#workflow.cwl_2/bgzip/file"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/bgzip/bgzipped_file"
                    ],
                    "id": "#workflow.cwl_2/bgzip"
                },
                {
                    "run": "#docm_filter.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/GATK_haplotype_caller/docm_out",
                            "id": "#workflow.cwl_2/docm_filter/docm_out"
                        },
                        {
                            "source": "#workflow.cwl_2/normal_cram",
                            "id": "#workflow.cwl_2/docm_filter/normal_cram"
                        },
                        {
                            "source": "#workflow.cwl_2/tumor_cram",
                            "id": "#workflow.cwl_2/docm_filter/tumor_cram"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/docm_filter/docm_filter_out"
                    ],
                    "id": "#workflow.cwl_2/docm_filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/bgzip/bgzipped_file",
                            "id": "#workflow.cwl_2/index/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/index/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_2/index"
                }
            ],
            "id": "#workflow.cwl_2"
        },
        {
            "class": "Workflow",
            "label": "exome alignment with qc",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#exome_alignment.cwl/bait_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#exome_alignment.cwl/bams"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#exome_alignment.cwl/bqsr_intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#exome_alignment.cwl/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#exome_alignment.cwl/known_indels"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#exome_alignment.cwl/mills"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#exome_alignment.cwl/omni_vcf"
                },
                {
                    "type": "File",
                    "id": "#exome_alignment.cwl/per_base_bait_intervals"
                },
                {
                    "type": "File",
                    "id": "#exome_alignment.cwl/per_base_intervals"
                },
                {
                    "type": "File",
                    "id": "#exome_alignment.cwl/per_target_bait_intervals"
                },
                {
                    "type": "File",
                    "id": "#exome_alignment.cwl/per_target_intervals"
                },
                {
                    "type": "string",
                    "id": "#exome_alignment.cwl/picard_metric_accumulation_level"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#exome_alignment.cwl/qc_minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#exome_alignment.cwl/qc_minimum_mapping_quality"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#exome_alignment.cwl/readgroups"
                },
                {
                    "type": "string",
                    "id": "#exome_alignment.cwl/reference"
                },
                {
                    "type": "File",
                    "id": "#exome_alignment.cwl/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#exome_alignment.cwl/qc/alignment_summary_metrics",
                    "id": "#exome_alignment.cwl/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#exome_alignment.cwl/alignment/final_cram",
                    "id": "#exome_alignment.cwl/cram"
                },
                {
                    "type": "File",
                    "outputSource": "#exome_alignment.cwl/qc/flagstats",
                    "id": "#exome_alignment.cwl/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#exome_alignment.cwl/qc/hs_metrics",
                    "id": "#exome_alignment.cwl/hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#exome_alignment.cwl/qc/insert_size_histogram",
                    "id": "#exome_alignment.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#exome_alignment.cwl/qc/insert_size_metrics",
                    "id": "#exome_alignment.cwl/insert_size_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#exome_alignment.cwl/alignment/mark_duplicates_metrics_file",
                    "id": "#exome_alignment.cwl/mark_duplicates_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#exome_alignment.cwl/qc/per_base_coverage_metrics",
                    "id": "#exome_alignment.cwl/per_base_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#exome_alignment.cwl/qc/per_base_hs_metrics",
                    "id": "#exome_alignment.cwl/per_base_hs_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#exome_alignment.cwl/qc/per_target_coverage_metrics",
                    "id": "#exome_alignment.cwl/per_target_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#exome_alignment.cwl/qc/per_target_hs_metrics",
                    "id": "#exome_alignment.cwl/per_target_hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#exome_alignment.cwl/qc/verify_bam_id_depth",
                    "id": "#exome_alignment.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#exome_alignment.cwl/qc/verify_bam_id_metrics",
                    "id": "#exome_alignment.cwl/verify_bam_id_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#workflow.cwl_7",
                    "in": [
                        {
                            "source": "#exome_alignment.cwl/bams",
                            "id": "#exome_alignment.cwl/alignment/bams"
                        },
                        {
                            "source": "#exome_alignment.cwl/bqsr_intervals",
                            "id": "#exome_alignment.cwl/alignment/bqsr_intervals"
                        },
                        {
                            "source": "#exome_alignment.cwl/dbsnp_vcf",
                            "id": "#exome_alignment.cwl/alignment/dbsnp_vcf"
                        },
                        {
                            "source": "#exome_alignment.cwl/known_indels",
                            "id": "#exome_alignment.cwl/alignment/known_indels"
                        },
                        {
                            "source": "#exome_alignment.cwl/mills",
                            "id": "#exome_alignment.cwl/alignment/mills"
                        },
                        {
                            "source": "#exome_alignment.cwl/readgroups",
                            "id": "#exome_alignment.cwl/alignment/readgroups"
                        },
                        {
                            "source": "#exome_alignment.cwl/reference",
                            "id": "#exome_alignment.cwl/alignment/reference"
                        }
                    ],
                    "out": [
                        "#exome_alignment.cwl/alignment/final_cram",
                        "#exome_alignment.cwl/alignment/mark_duplicates_metrics_file"
                    ],
                    "id": "#exome_alignment.cwl/alignment"
                },
                {
                    "run": "#workflow_exome.cwl",
                    "in": [
                        {
                            "source": "#exome_alignment.cwl/bait_intervals",
                            "id": "#exome_alignment.cwl/qc/bait_intervals"
                        },
                        {
                            "source": "#exome_alignment.cwl/alignment/final_cram",
                            "id": "#exome_alignment.cwl/qc/cram"
                        },
                        {
                            "source": "#exome_alignment.cwl/qc_minimum_base_quality",
                            "id": "#exome_alignment.cwl/qc/minimum_base_quality"
                        },
                        {
                            "source": "#exome_alignment.cwl/qc_minimum_mapping_quality",
                            "id": "#exome_alignment.cwl/qc/minimum_mapping_quality"
                        },
                        {
                            "source": "#exome_alignment.cwl/omni_vcf",
                            "id": "#exome_alignment.cwl/qc/omni_vcf"
                        },
                        {
                            "source": "#exome_alignment.cwl/per_base_bait_intervals",
                            "id": "#exome_alignment.cwl/qc/per_base_bait_intervals"
                        },
                        {
                            "source": "#exome_alignment.cwl/per_base_intervals",
                            "id": "#exome_alignment.cwl/qc/per_base_intervals"
                        },
                        {
                            "source": "#exome_alignment.cwl/per_target_bait_intervals",
                            "id": "#exome_alignment.cwl/qc/per_target_bait_intervals"
                        },
                        {
                            "source": "#exome_alignment.cwl/per_target_intervals",
                            "id": "#exome_alignment.cwl/qc/per_target_intervals"
                        },
                        {
                            "source": "#exome_alignment.cwl/picard_metric_accumulation_level",
                            "id": "#exome_alignment.cwl/qc/picard_metric_accumulation_level"
                        },
                        {
                            "source": "#exome_alignment.cwl/reference",
                            "id": "#exome_alignment.cwl/qc/reference"
                        },
                        {
                            "source": "#exome_alignment.cwl/target_intervals",
                            "id": "#exome_alignment.cwl/qc/target_intervals"
                        }
                    ],
                    "out": [
                        "#exome_alignment.cwl/qc/insert_size_metrics",
                        "#exome_alignment.cwl/qc/insert_size_histogram",
                        "#exome_alignment.cwl/qc/alignment_summary_metrics",
                        "#exome_alignment.cwl/qc/hs_metrics",
                        "#exome_alignment.cwl/qc/per_target_coverage_metrics",
                        "#exome_alignment.cwl/qc/per_target_hs_metrics",
                        "#exome_alignment.cwl/qc/per_base_coverage_metrics",
                        "#exome_alignment.cwl/qc/per_base_hs_metrics",
                        "#exome_alignment.cwl/qc/flagstats",
                        "#exome_alignment.cwl/qc/verify_bam_id_metrics",
                        "#exome_alignment.cwl/qc/verify_bam_id_depth"
                    ],
                    "id": "#exome_alignment.cwl/qc"
                }
            ],
            "id": "#exome_alignment.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "False Positive filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/fpfilter.pl"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "--bam-readcount",
                "/usr/bin/bam-readcount",
                "--samtools",
                "/opt/samtools/bin/samtools",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bam-file",
                        "position": 2
                    },
                    "id": "#fp_filter.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.05,
                    "inputBinding": {
                        "prefix": "--min-var-freq",
                        "position": 5
                    },
                    "id": "#fp_filter.cwl/min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "fpfilter",
                    "id": "#fp_filter.cwl/output_vcf_basename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--reference",
                        "position": 1
                    },
                    "id": "#fp_filter.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "TUMOR",
                    "inputBinding": {
                        "prefix": "--sample",
                        "position": 4
                    },
                    "id": "#fp_filter.cwl/sample_name"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--vcf-file",
                        "position": 3
                    },
                    "id": "#fp_filter.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf"
                    },
                    "id": "#fp_filter.cwl/filtered_vcf"
                }
            ],
            "id": "#fp_filter.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Normalize variants",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "LeftAlignAndTrimVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "arguments": [
                "--splitMultiallelics",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/normalized.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#normalize_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#normalize_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "normalized.vcf.gz"
                    },
                    "id": "#normalize_variants.cwl/normalized_vcf"
                }
            ],
            "id": "#normalize_variants.cwl"
        },
        {
            "class": "Workflow",
            "label": "fp_filter workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_3/cram"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#workflow.cwl_3/min_var_freq"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_3/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#workflow.cwl_3/sample_name"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_3/variant_caller"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_3/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_3/hard_filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_3/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_3/fp_index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_3/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#workflow.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_3/cram",
                            "id": "#workflow.cwl_3/cram_to_bam/cram"
                        },
                        {
                            "source": "#workflow.cwl_3/reference",
                            "id": "#workflow.cwl_3/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/cram_to_bam/bam"
                    ],
                    "id": "#workflow.cwl_3/cram_to_bam"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_3/fp_filter/filtered_vcf",
                            "id": "#workflow.cwl_3/fp_bgzip/file"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/fp_bgzip/bgzipped_file"
                    ],
                    "id": "#workflow.cwl_3/fp_bgzip"
                },
                {
                    "run": "#fp_filter.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_3/cram_to_bam/bam",
                            "id": "#workflow.cwl_3/fp_filter/bam"
                        },
                        {
                            "source": "#workflow.cwl_3/min_var_freq",
                            "id": "#workflow.cwl_3/fp_filter/min_var_freq"
                        },
                        {
                            "source": "#workflow.cwl_3/variant_caller",
                            "valueFrom": "$(self)_full",
                            "id": "#workflow.cwl_3/fp_filter/output_vcf_basename"
                        },
                        {
                            "source": "#workflow.cwl_3/reference",
                            "id": "#workflow.cwl_3/fp_filter/reference"
                        },
                        {
                            "source": "#workflow.cwl_3/sample_name",
                            "id": "#workflow.cwl_3/fp_filter/sample_name"
                        },
                        {
                            "source": "#workflow.cwl_3/normalize_variants/normalized_vcf",
                            "id": "#workflow.cwl_3/fp_filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/fp_filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_3/fp_filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_3/fp_bgzip/bgzipped_file",
                            "id": "#workflow.cwl_3/fp_index/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/fp_index/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_3/fp_index"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#workflow.cwl_3/hard_filter/exclude_filtered"
                        },
                        {
                            "source": "#workflow.cwl_3/variant_caller",
                            "valueFrom": "$(self)_filtered",
                            "id": "#workflow.cwl_3/hard_filter/output_vcf_basename"
                        },
                        {
                            "source": "#workflow.cwl_3/reference",
                            "id": "#workflow.cwl_3/hard_filter/reference"
                        },
                        {
                            "source": "#workflow.cwl_3/fp_index/indexed_vcf",
                            "id": "#workflow.cwl_3/hard_filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/hard_filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_3/hard_filter"
                },
                {
                    "run": "#normalize_variants.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_3/reference",
                            "id": "#workflow.cwl_3/normalize_variants/reference"
                        },
                        {
                            "source": "#workflow.cwl_3/vcf",
                            "id": "#workflow.cwl_3/normalize_variants/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/normalize_variants/normalized_vcf"
                    ],
                    "id": "#workflow.cwl_3/normalize_variants"
                }
            ],
            "id": "#workflow.cwl_3"
        },
        {
            "class": "CommandLineTool",
            "label": "mutect2 (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "MuTect2"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 20000,
                    "tmpdirMin": 100000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/mutect.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--artifact_detection_mode",
                        "position": 7
                    },
                    "id": "#mutect.cwl/artifact_detection_mode"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--cosmic",
                        "position": 6
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#mutect.cwl/cosmic_vcf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--dbsnp",
                        "position": 5
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#mutect.cwl/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 4
                    },
                    "id": "#mutect.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--max_alt_allele_in_normal_fraction",
                        "position": 10
                    },
                    "id": "#mutect.cwl/max_alt_allele_in_normal_fraction"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max_alt_alleles_in_normal_count",
                        "position": 9
                    },
                    "id": "#mutect.cwl/max_alt_alleles_in_normal_count"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-I:normal",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".crai"
                    ],
                    "id": "#mutect.cwl/normal_cram"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-PON",
                        "position": 8
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#mutect.cwl/panel_of_normals_vcf"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#mutect.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I:tumor",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".crai"
                    ],
                    "id": "#mutect.cwl/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mutect.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#mutect.cwl/vcf"
                }
            ],
            "id": "#mutect.cwl"
        },
        {
            "class": "Workflow",
            "label": "mutect parallel workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "id": "#workflow.cwl_4/artifact_detection_mode"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_4/cosmic_vcf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_4/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "id": "#workflow.cwl_4/interval_list"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#workflow.cwl_4/max_alt_allele_in_normal_fraction"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#workflow.cwl_4/max_alt_alleles_in_normal_count"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".crai"
                    ],
                    "id": "#workflow.cwl_4/normal_cram"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_4/panel_of_normals_vcf"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_4/reference"
                },
                {
                    "type": "int",
                    "id": "#workflow.cwl_4/scatter_count"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai"
                    ],
                    "id": "#workflow.cwl_4/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_4/filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_4/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_4/filter/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_4/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#workflow.cwl_3",
                    "in": [
                        {
                            "source": "#workflow.cwl_4/tumor_cram",
                            "id": "#workflow.cwl_4/filter/cram"
                        },
                        {
                            "source": "#workflow.cwl_4/reference",
                            "id": "#workflow.cwl_4/filter/reference"
                        },
                        {
                            "valueFrom": "mutect",
                            "id": "#workflow.cwl_4/filter/variant_caller"
                        },
                        {
                            "source": "#workflow.cwl_4/index/indexed_vcf",
                            "id": "#workflow.cwl_4/filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_4/filter/unfiltered_vcf",
                        "#workflow.cwl_4/filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_4/filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_4/merge/merged_vcf",
                            "id": "#workflow.cwl_4/index/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_4/index/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_4/index"
                },
                {
                    "run": "#merge.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_4/mutect/vcf",
                            "id": "#workflow.cwl_4/merge/vcfs"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_4/merge/merged_vcf"
                    ],
                    "id": "#workflow.cwl_4/merge"
                },
                {
                    "scatter": "#workflow.cwl_4/mutect/interval_list",
                    "run": "#mutect.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_4/artifact_detection_mode",
                            "id": "#workflow.cwl_4/mutect/artifact_detection_mode"
                        },
                        {
                            "source": "#workflow.cwl_4/cosmic_vcf",
                            "id": "#workflow.cwl_4/mutect/cosmic_vcf"
                        },
                        {
                            "source": "#workflow.cwl_4/dbsnp_vcf",
                            "id": "#workflow.cwl_4/mutect/dbsnp_vcf"
                        },
                        {
                            "source": "#workflow.cwl_4/split_interval_list/split_interval_lists",
                            "id": "#workflow.cwl_4/mutect/interval_list"
                        },
                        {
                            "source": "#workflow.cwl_4/max_alt_allele_in_normal_fraction",
                            "id": "#workflow.cwl_4/mutect/max_alt_allele_in_normal_fraction"
                        },
                        {
                            "source": "#workflow.cwl_4/max_alt_alleles_in_normal_count",
                            "id": "#workflow.cwl_4/mutect/max_alt_alleles_in_normal_count"
                        },
                        {
                            "source": "#workflow.cwl_4/normal_cram",
                            "id": "#workflow.cwl_4/mutect/normal_cram"
                        },
                        {
                            "source": "#workflow.cwl_4/panel_of_normals_vcf",
                            "id": "#workflow.cwl_4/mutect/panel_of_normals_vcf"
                        },
                        {
                            "source": "#workflow.cwl_4/reference",
                            "id": "#workflow.cwl_4/mutect/reference"
                        },
                        {
                            "source": "#workflow.cwl_4/tumor_cram",
                            "id": "#workflow.cwl_4/mutect/tumor_cram"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_4/mutect/vcf"
                    ],
                    "id": "#workflow.cwl_4/mutect"
                },
                {
                    "run": "#split_interval_list.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_4/interval_list",
                            "id": "#workflow.cwl_4/split_interval_list/interval_list"
                        },
                        {
                            "source": "#workflow.cwl_4/scatter_count",
                            "id": "#workflow.cwl_4/split_interval_list/scatter_count"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_4/split_interval_list/split_interval_lists"
                    ],
                    "id": "#workflow.cwl_4/split_interval_list"
                }
            ],
            "id": "#workflow.cwl_4"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/cat"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "arguments": [
                {
                    "shellQuote": false,
                    "valueFrom": "|"
                },
                "/bin/grep",
                "ChrID",
                "/dev/stdin"
            ],
            "stdout": "all_chromosome_pindel.head",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#cat_all.cwl/chromosome_pindel_outs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#cat_all.cwl/all_chromosome_pindel_head",
                    "outputBinding": {
                        "glob": "all_chromosome_pindel.head"
                    }
                }
            ],
            "id": "#cat_all.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/cat"
            ],
            "stdout": "per_chromosome_pindel.out",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cat_out.cwl/pindel_outs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#cat_out.cwl/pindel_out",
                    "outputBinding": {
                        "glob": "per_chromosome_pindel.out"
                    }
                }
            ],
            "id": "#cat_out.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "bash",
                "-c",
                "/bin/grep -v '^@' $1 | /usr/bin/cut -f 1 | /usr/bin/sort | /usr/bin/uniq",
                "--"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "chromosome.list",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#get_chromosome_list.cwl/interval_list"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "outputBinding": {
                        "glob": "chromosome.list",
                        "loadContents": true,
                        "outputEval": "$( self[0].contents.split(\"\\n\").slice(0, -1))"
                    },
                    "id": "#get_chromosome_list.cwl/chromosome_list"
                }
            ],
            "id": "#get_chromosome_list.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "pindel v0.2.5b8",
            "arguments": [
                "/usr/bin/perl",
                "/usr/bin/pindel_helper.pl",
                "$(inputs.normal_cram.path)",
                "$(inputs.tumor_cram.path)",
                "$(inputs.insert_size)"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "tmpdirMin": 100000
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-c",
                        "position": 2
                    },
                    "id": "#pindel.cwl/chromosome"
                },
                {
                    "type": "int",
                    "default": 400,
                    "id": "#pindel.cwl/insert_size"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#pindel.cwl/normal_cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-f",
                        "position": 1
                    },
                    "id": "#pindel.cwl/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#pindel.cwl/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_D"
                    },
                    "id": "#pindel.cwl/deletions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_SI"
                    },
                    "id": "#pindel.cwl/insertions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_INV"
                    },
                    "id": "#pindel.cwl/inversions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_LI"
                    },
                    "id": "#pindel.cwl/long_insertions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_TD"
                    },
                    "id": "#pindel.cwl/tandems"
                }
            ],
            "id": "#pindel.cwl"
        },
        {
            "class": "Workflow",
            "label": "Per-chromosome pindel",
            "requirements": [
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#pindel_cat.cwl/chromosome"
                },
                {
                    "type": "int",
                    "default": 400,
                    "id": "#pindel_cat.cwl/insert_size"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#pindel_cat.cwl/normal_cram"
                },
                {
                    "type": "string",
                    "id": "#pindel_cat.cwl/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#pindel_cat.cwl/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#pindel_cat.cwl/cat/pindel_out",
                    "id": "#pindel_cat.cwl/per_chromosome_pindel_out"
                }
            ],
            "steps": [
                {
                    "run": "#cat_out.cwl",
                    "in": [
                        {
                            "source": [
                                "#pindel_cat.cwl/pindel/deletions",
                                "#pindel_cat.cwl/pindel/insertions",
                                "#pindel_cat.cwl/pindel/tandems",
                                "#pindel_cat.cwl/pindel/long_insertions",
                                "#pindel_cat.cwl/pindel/inversions"
                            ],
                            "id": "#pindel_cat.cwl/cat/pindel_outs"
                        }
                    ],
                    "out": [
                        "#pindel_cat.cwl/cat/pindel_out"
                    ],
                    "id": "#pindel_cat.cwl/cat"
                },
                {
                    "run": "#pindel.cwl",
                    "in": [
                        {
                            "source": "#pindel_cat.cwl/chromosome",
                            "id": "#pindel_cat.cwl/pindel/chromosome"
                        },
                        {
                            "source": "#pindel_cat.cwl/insert_size",
                            "id": "#pindel_cat.cwl/pindel/insert_size"
                        },
                        {
                            "source": "#pindel_cat.cwl/normal_cram",
                            "id": "#pindel_cat.cwl/pindel/normal_cram"
                        },
                        {
                            "source": "#pindel_cat.cwl/reference",
                            "id": "#pindel_cat.cwl/pindel/reference"
                        },
                        {
                            "source": "#pindel_cat.cwl/tumor_cram",
                            "id": "#pindel_cat.cwl/pindel/tumor_cram"
                        }
                    ],
                    "out": [
                        "#pindel_cat.cwl/pindel/deletions",
                        "#pindel_cat.cwl/pindel/insertions",
                        "#pindel_cat.cwl/pindel/tandems",
                        "#pindel_cat.cwl/pindel/long_insertions",
                        "#pindel_cat.cwl/pindel/inversions"
                    ],
                    "id": "#pindel_cat.cwl/pindel"
                }
            ],
            "id": "#pindel_cat.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "remove END INFO tags",
            "baseCommand": [
                "/opt/bcftools/bin/bcftools",
                "annotate"
            ],
            "arguments": [
                "-x",
                "INFO/END",
                "-Oz",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/pindel.noend.vcf.gz"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#remove_end_tags.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "pindel.noend.vcf.gz"
                    },
                    "id": "#remove_end_tags.cwl/processed_vcf"
                }
            ],
            "id": "#remove_end_tags.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "pindel somatic filter v1",
            "arguments": [
                "/usr/bin/perl",
                "/usr/bin/write_pindel_filter_config.pl",
                "$(inputs.pindel_output_summary.path)",
                "$(inputs.reference)",
                "$(runtime.outdir)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/perl",
                "/usr/bin/somatic_indelfilter.pl",
                "filter.config"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#somaticfilter.cwl/pindel_output_summary"
                },
                {
                    "type": "string",
                    "id": "#somaticfilter.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "pindel.out.vcf"
                    },
                    "id": "#somaticfilter.cwl/vcf"
                }
            ],
            "id": "#somaticfilter.cwl"
        },
        {
            "class": "Workflow",
            "label": "pindel parallel workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "default": 400,
                    "id": "#workflow.cwl_5/insert_size"
                },
                {
                    "type": "File",
                    "id": "#workflow.cwl_5/interval_list"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_5/normal_cram"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_5/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_5/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_5/filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_5/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_5/filter/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_5/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/somaticfilter/vcf",
                            "id": "#workflow.cwl_5/bgzip/file"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/bgzip/bgzipped_file"
                    ],
                    "id": "#workflow.cwl_5/bgzip"
                },
                {
                    "run": "#cat_all.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/pindel_cat/per_chromosome_pindel_out",
                            "id": "#workflow.cwl_5/cat_all/chromosome_pindel_outs"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/cat_all/all_chromosome_pindel_head"
                    ],
                    "id": "#workflow.cwl_5/cat_all"
                },
                {
                    "run": "#workflow.cwl_3",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/tumor_cram",
                            "id": "#workflow.cwl_5/filter/cram"
                        },
                        {
                            "source": "#workflow.cwl_5/reference",
                            "id": "#workflow.cwl_5/filter/reference"
                        },
                        {
                            "valueFrom": "pindel",
                            "id": "#workflow.cwl_5/filter/variant_caller"
                        },
                        {
                            "source": "#workflow.cwl_5/reindex/indexed_vcf",
                            "id": "#workflow.cwl_5/filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/filter/unfiltered_vcf",
                        "#workflow.cwl_5/filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_5/filter"
                },
                {
                    "run": "#get_chromosome_list.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/interval_list",
                            "id": "#workflow.cwl_5/get_chromosome_list/interval_list"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/get_chromosome_list/chromosome_list"
                    ],
                    "id": "#workflow.cwl_5/get_chromosome_list"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/bgzip/bgzipped_file",
                            "id": "#workflow.cwl_5/index/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/index/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_5/index"
                },
                {
                    "scatter": "#workflow.cwl_5/pindel_cat/chromosome",
                    "run": "#pindel_cat.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/get_chromosome_list/chromosome_list",
                            "id": "#workflow.cwl_5/pindel_cat/chromosome"
                        },
                        {
                            "source": "#workflow.cwl_5/insert_size",
                            "id": "#workflow.cwl_5/pindel_cat/insert_size"
                        },
                        {
                            "source": "#workflow.cwl_5/normal_cram",
                            "id": "#workflow.cwl_5/pindel_cat/normal_cram"
                        },
                        {
                            "source": "#workflow.cwl_5/reference",
                            "id": "#workflow.cwl_5/pindel_cat/reference"
                        },
                        {
                            "source": "#workflow.cwl_5/tumor_cram",
                            "id": "#workflow.cwl_5/pindel_cat/tumor_cram"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/pindel_cat/per_chromosome_pindel_out"
                    ],
                    "id": "#workflow.cwl_5/pindel_cat"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/interval_list",
                            "id": "#workflow.cwl_5/region_filter/interval_list"
                        },
                        {
                            "source": "#workflow.cwl_5/reference",
                            "id": "#workflow.cwl_5/region_filter/reference"
                        },
                        {
                            "source": "#workflow.cwl_5/index/indexed_vcf",
                            "id": "#workflow.cwl_5/region_filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/region_filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_5/region_filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/remove_end_tags/processed_vcf",
                            "id": "#workflow.cwl_5/reindex/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/reindex/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_5/reindex"
                },
                {
                    "run": "#remove_end_tags.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/region_filter/filtered_vcf",
                            "id": "#workflow.cwl_5/remove_end_tags/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/remove_end_tags/processed_vcf"
                    ],
                    "id": "#workflow.cwl_5/remove_end_tags"
                },
                {
                    "run": "#somaticfilter.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/cat_all/all_chromosome_pindel_head",
                            "id": "#workflow.cwl_5/somaticfilter/pindel_output_summary"
                        },
                        {
                            "source": "#workflow.cwl_5/reference",
                            "id": "#workflow.cwl_5/somaticfilter/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/somaticfilter/vcf"
                    ],
                    "id": "#workflow.cwl_5/somaticfilter"
                }
            ],
            "id": "#workflow.cwl_5"
        },
        {
            "class": "CommandLineTool",
            "label": "run bam-readcount",
            "baseCommand": [
                "/usr/bin/python",
                "/usr/bin/bam_readcount_helper.py"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "arguments": [
                "$(runtime.outdir)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/bin/cat",
                "$(runtime.outdir)/$(inputs.sample)_bam_readcount_snv.tsv",
                "$(runtime.outdir)/$(inputs.sample)_bam_readcount_indel.tsv"
            ],
            "stdout": "$(inputs.sample)_bam_readcount.tsv",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -3
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bam_readcount.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20,
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#bam_readcount.cwl/min_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#bam_readcount.cwl/min_mapping_quality"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -4
                    },
                    "id": "#bam_readcount.cwl/reference_fasta"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -5
                    },
                    "id": "#bam_readcount.cwl/sample"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -6
                    },
                    "id": "#bam_readcount.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bam_readcount.cwl/bam_readcount_tsv",
                    "outputBinding": {
                        "glob": "$(inputs.sample)_bam_readcount.tsv"
                    }
                }
            ],
            "id": "#bam_readcount.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect alignment summary metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectAlignmentSummaryMetrics"
            ],
            "arguments": [
                "OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/AlignmentSummaryMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_alignment_summary_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "AlignmentSummaryMetrics.txt"
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/alignment_summary_metrics"
                }
            ],
            "id": "#collect_alignment_summary_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect HS metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectHsMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_prefix)-HsMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "BAIT_INTERVALS="
                    },
                    "id": "#collect_hs_metrics.cwl/bait_intervals"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_hs_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_hs_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "MINIMUM_BASE_QUALITY="
                    },
                    "id": "#collect_hs_metrics.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "MINIMUM_MAPPING_QUALITY="
                    },
                    "id": "#collect_hs_metrics.cwl/minimum_mapping_quality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "out",
                    "id": "#collect_hs_metrics.cwl/output_prefix"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "PER_BASE_COVERAGE=",
                        "valueFrom": "${\n    if(self) {\n        return inputs.output_prefix + \"-PerBaseCoverage.txt\"\n    } else {\n        return false;\n    }\n}\n"
                    },
                    "id": "#collect_hs_metrics.cwl/per_base_coverage"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "PER_TARGET_COVERAGE=",
                        "valueFrom": "${\n    if(self) {\n        return inputs.output_prefix + \"-PerTargetCoverage.txt\"\n    } else {\n        return false;\n    }\n}\n"
                    },
                    "id": "#collect_hs_metrics.cwl/per_target_coverage"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "id": "#collect_hs_metrics.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "TARGET_INTERVALS="
                    },
                    "id": "#collect_hs_metrics.cwl/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(input.output_prefix)-HsMetrics.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/hs_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(input.output_prefix)-PerBaseCoverage.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/per_base_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(input.output_prefix)-PerTargetCoverage.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/per_target_coverage_metrics"
                }
            ],
            "id": "#collect_hs_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect insert size metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectInsertSizeMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/InsertSizeMetrics.txt"
                },
                "H=",
                {
                    "valueFrom": "$(runtime.outdir)/InsertSizeHistogram.pdf"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_insert_size_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_insert_size_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#collect_insert_size_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "InsertSizeHistogram.pdf"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "InsertSizeMetrics.txt"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_metrics"
                }
            ],
            "id": "#collect_insert_size_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools flagstat",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "flagstat"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "flagstat.out",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#samtools_flagstat.cwl/cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#samtools_flagstat.cwl/flagstats",
                    "outputBinding": {
                        "glob": "flagstat.out"
                    }
                }
            ],
            "id": "#samtools_flagstat.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "verify BAM ID",
            "baseCommand": "/usr/local/bin/verifyBamID",
            "arguments": [
                "--out",
                {
                    "valueFrom": "$(runtime.outdir)/VerifyBamId"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bam"
                    },
                    "id": "#verify_bam_id.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--vcf"
                    },
                    "id": "#verify_bam_id.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "VerifyBamId.depthSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "VerifyBamId.selfSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_metrics"
                }
            ],
            "id": "#verify_bam_id.cwl"
        },
        {
            "class": "Workflow",
            "label": "Exome QC workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#workflow_exome.cwl/bait_intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow_exome.cwl/cram"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#workflow_exome.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#workflow_exome.cwl/minimum_mapping_quality"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow_exome.cwl/omni_vcf"
                },
                {
                    "type": "File",
                    "id": "#workflow_exome.cwl/per_base_bait_intervals"
                },
                {
                    "type": "File",
                    "id": "#workflow_exome.cwl/per_base_intervals"
                },
                {
                    "type": "File",
                    "id": "#workflow_exome.cwl/per_target_bait_intervals"
                },
                {
                    "type": "File",
                    "id": "#workflow_exome.cwl/per_target_intervals"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "ALL_READS",
                    "id": "#workflow_exome.cwl/picard_metric_accumulation_level"
                },
                {
                    "type": "string",
                    "id": "#workflow_exome.cwl/reference"
                },
                {
                    "type": "File",
                    "id": "#workflow_exome.cwl/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow_exome.cwl/collect_alignment_summary_metrics/alignment_summary_metrics",
                    "id": "#workflow_exome.cwl/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_exome.cwl/samtools_flagstat/flagstats",
                    "id": "#workflow_exome.cwl/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_exome.cwl/collect_roi_hs_metrics/hs_metrics",
                    "id": "#workflow_exome.cwl/hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_exome.cwl/collect_insert_size_metrics/insert_size_histogram",
                    "id": "#workflow_exome.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_exome.cwl/collect_insert_size_metrics/insert_size_metrics",
                    "id": "#workflow_exome.cwl/insert_size_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#workflow_exome.cwl/collect_per_base_hs_metrics/per_base_coverage_metrics",
                    "id": "#workflow_exome.cwl/per_base_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#workflow_exome.cwl/collect_per_base_hs_metrics/hs_metrics",
                    "id": "#workflow_exome.cwl/per_base_hs_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#workflow_exome.cwl/collect_per_target_hs_metrics/per_target_coverage_metrics",
                    "id": "#workflow_exome.cwl/per_target_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#workflow_exome.cwl/collect_per_target_hs_metrics/hs_metrics",
                    "id": "#workflow_exome.cwl/per_target_hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_exome.cwl/verify_bam_id/verify_bam_id_depth",
                    "id": "#workflow_exome.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_exome.cwl/verify_bam_id/verify_bam_id_metrics",
                    "id": "#workflow_exome.cwl/verify_bam_id_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#collect_alignment_summary_metrics.cwl",
                    "in": [
                        {
                            "source": "#workflow_exome.cwl/cram",
                            "id": "#workflow_exome.cwl/collect_alignment_summary_metrics/cram"
                        },
                        {
                            "source": "#workflow_exome.cwl/picard_metric_accumulation_level",
                            "id": "#workflow_exome.cwl/collect_alignment_summary_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#workflow_exome.cwl/reference",
                            "id": "#workflow_exome.cwl/collect_alignment_summary_metrics/reference"
                        }
                    ],
                    "out": [
                        "#workflow_exome.cwl/collect_alignment_summary_metrics/alignment_summary_metrics"
                    ],
                    "id": "#workflow_exome.cwl/collect_alignment_summary_metrics"
                },
                {
                    "run": "#collect_insert_size_metrics.cwl",
                    "in": [
                        {
                            "source": "#workflow_exome.cwl/cram",
                            "id": "#workflow_exome.cwl/collect_insert_size_metrics/cram"
                        },
                        {
                            "source": "#workflow_exome.cwl/picard_metric_accumulation_level",
                            "id": "#workflow_exome.cwl/collect_insert_size_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#workflow_exome.cwl/reference",
                            "id": "#workflow_exome.cwl/collect_insert_size_metrics/reference"
                        }
                    ],
                    "out": [
                        "#workflow_exome.cwl/collect_insert_size_metrics/insert_size_metrics",
                        "#workflow_exome.cwl/collect_insert_size_metrics/insert_size_histogram"
                    ],
                    "id": "#workflow_exome.cwl/collect_insert_size_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "in": [
                        {
                            "source": "#workflow_exome.cwl/per_base_bait_intervals",
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#workflow_exome.cwl/cram",
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/cram"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#workflow_exome.cwl/minimum_base_quality",
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#workflow_exome.cwl/minimum_mapping_quality",
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "valueFrom": "base",
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/output_prefix"
                        },
                        {
                            "default": true,
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": false,
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#workflow_exome.cwl/reference",
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/reference"
                        },
                        {
                            "source": "#workflow_exome.cwl/per_base_intervals",
                            "id": "#workflow_exome.cwl/collect_per_base_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#workflow_exome.cwl/collect_per_base_hs_metrics/hs_metrics",
                        "#workflow_exome.cwl/collect_per_base_hs_metrics/per_base_coverage_metrics"
                    ],
                    "id": "#workflow_exome.cwl/collect_per_base_hs_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "in": [
                        {
                            "source": "#workflow_exome.cwl/per_target_bait_intervals",
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#workflow_exome.cwl/cram",
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/cram"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#workflow_exome.cwl/minimum_base_quality",
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#workflow_exome.cwl/minimum_mapping_quality",
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "valueFrom": "target",
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/output_prefix"
                        },
                        {
                            "default": false,
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": true,
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#workflow_exome.cwl/reference",
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/reference"
                        },
                        {
                            "source": "#workflow_exome.cwl/per_target_intervals",
                            "id": "#workflow_exome.cwl/collect_per_target_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#workflow_exome.cwl/collect_per_target_hs_metrics/hs_metrics",
                        "#workflow_exome.cwl/collect_per_target_hs_metrics/per_target_coverage_metrics"
                    ],
                    "id": "#workflow_exome.cwl/collect_per_target_hs_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "in": [
                        {
                            "source": "#workflow_exome.cwl/bait_intervals",
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#workflow_exome.cwl/cram",
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/cram"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#workflow_exome.cwl/minimum_base_quality",
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#workflow_exome.cwl/minimum_mapping_quality",
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "valueFrom": "roi",
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/output_prefix"
                        },
                        {
                            "default": false,
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": false,
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#workflow_exome.cwl/reference",
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/reference"
                        },
                        {
                            "source": "#workflow_exome.cwl/target_intervals",
                            "id": "#workflow_exome.cwl/collect_roi_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#workflow_exome.cwl/collect_roi_hs_metrics/hs_metrics"
                    ],
                    "id": "#workflow_exome.cwl/collect_roi_hs_metrics"
                },
                {
                    "run": "#workflow.cwl",
                    "in": [
                        {
                            "source": "#workflow_exome.cwl/cram",
                            "id": "#workflow_exome.cwl/cram_to_bam/cram"
                        },
                        {
                            "source": "#workflow_exome.cwl/reference",
                            "id": "#workflow_exome.cwl/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#workflow_exome.cwl/cram_to_bam/bam"
                    ],
                    "id": "#workflow_exome.cwl/cram_to_bam"
                },
                {
                    "run": "#samtools_flagstat.cwl",
                    "in": [
                        {
                            "source": "#workflow_exome.cwl/cram",
                            "id": "#workflow_exome.cwl/samtools_flagstat/cram"
                        }
                    ],
                    "out": [
                        "#workflow_exome.cwl/samtools_flagstat/flagstats"
                    ],
                    "id": "#workflow_exome.cwl/samtools_flagstat"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "source": "#workflow_exome.cwl/target_intervals",
                            "id": "#workflow_exome.cwl/select_variants/interval_list"
                        },
                        {
                            "source": "#workflow_exome.cwl/reference",
                            "id": "#workflow_exome.cwl/select_variants/reference"
                        },
                        {
                            "source": "#workflow_exome.cwl/omni_vcf",
                            "id": "#workflow_exome.cwl/select_variants/vcf"
                        }
                    ],
                    "out": [
                        "#workflow_exome.cwl/select_variants/filtered_vcf"
                    ],
                    "id": "#workflow_exome.cwl/select_variants"
                },
                {
                    "run": "#verify_bam_id.cwl",
                    "in": [
                        {
                            "source": "#workflow_exome.cwl/cram_to_bam/bam",
                            "id": "#workflow_exome.cwl/verify_bam_id/bam"
                        },
                        {
                            "source": "#workflow_exome.cwl/select_variants/filtered_vcf",
                            "id": "#workflow_exome.cwl/verify_bam_id/vcf"
                        }
                    ],
                    "out": [
                        "#workflow_exome.cwl/verify_bam_id/verify_bam_id_metrics",
                        "#workflow_exome.cwl/verify_bam_id/verify_bam_id_depth"
                    ],
                    "id": "#workflow_exome.cwl/verify_bam_id"
                }
            ],
            "id": "#workflow_exome.cwl"
        },
        {
            "class": "Workflow",
            "label": "exome alignment and somatic variant detection",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/annotate_coding_only"
                },
                {
                    "type": "File",
                    "id": "#main/bait_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/bqsr_intervals"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "id": "#main/cle_vcf_filter"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/cosmic_vcf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/custom_gnomad_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/docm_vcf"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/hgvs_annotation"
                },
                {
                    "type": "File",
                    "id": "#main/interval_list"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/known_indels"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/mills"
                },
                {
                    "type": "boolean",
                    "id": "#main/mutect_artifact_detection_mode"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#main/mutect_max_alt_allele_in_normal_fraction"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/mutect_max_alt_alleles_in_normal_count"
                },
                {
                    "type": "int",
                    "id": "#main/mutect_scatter_count"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/normal_bams"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/normal_readgroups"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/omni_vcf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/panel_of_normals_vcf"
                },
                {
                    "type": "File",
                    "id": "#main/per_base_bait_intervals"
                },
                {
                    "type": "File",
                    "id": "#main/per_base_intervals"
                },
                {
                    "type": "File",
                    "id": "#main/per_target_bait_intervals"
                },
                {
                    "type": "File",
                    "id": "#main/per_target_intervals"
                },
                {
                    "type": "string",
                    "id": "#main/picard_metric_accumulation_level"
                },
                {
                    "type": "int",
                    "default": 400,
                    "id": "#main/pindel_insert_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "id": "#main/qc_minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "id": "#main/qc_minimum_mapping_quality"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#main/strelka_cpu_reserved"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/synonyms_file"
                },
                {
                    "type": "File",
                    "id": "#main/target_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/tumor_bams"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/tumor_readgroups"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "CHROM",
                        "POS",
                        "ID",
                        "REF",
                        "ALT",
                        "set",
                        "AC",
                        "AF"
                    ],
                    "id": "#main/variants_to_table_fields"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "GT",
                        "AD"
                    ],
                    "id": "#main/variants_to_table_genotype_fields"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#main/varscan_max_normal_freq"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#main/varscan_min_coverage"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.05,
                    "id": "#main/varscan_min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "id": "#main/varscan_p_value"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "id": "#main/varscan_strand_filter"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/vep_cache_dir"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "HGVSc",
                        "HGVSp"
                    ],
                    "id": "#main/vep_to_table_fields"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/docm_filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/docm_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/docm_unfiltered_vcf",
                    "id": "#main/docm_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/final_filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/final_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/final_tsv",
                    "id": "#main/final_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/final_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/final_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/mutect_filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/mutect_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/mutect_unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/mutect_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/normal_alignment_and_qc/alignment_summary_metrics",
                    "id": "#main/normal_alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/normal_bam_readcount_tsv",
                    "id": "#main/normal_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/normal_alignment_and_qc/cram",
                    "id": "#main/normal_cram"
                },
                {
                    "type": "File",
                    "outputSource": "#main/normal_alignment_and_qc/flagstats",
                    "id": "#main/normal_flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#main/normal_alignment_and_qc/hs_metrics",
                    "id": "#main/normal_hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/normal_alignment_and_qc/insert_size_metrics",
                    "id": "#main/normal_insert_size_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/normal_alignment_and_qc/mark_duplicates_metrics",
                    "id": "#main/normal_mark_duplicates_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/normal_alignment_and_qc/per_base_coverage_metrics",
                    "id": "#main/normal_per_base_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/normal_alignment_and_qc/per_base_hs_metrics",
                    "id": "#main/normal_per_base_hs_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/normal_alignment_and_qc/per_target_coverage_metrics",
                    "id": "#main/normal_per_target_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/normal_alignment_and_qc/per_target_hs_metrics",
                    "id": "#main/normal_per_target_hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/normal_alignment_and_qc/verify_bam_id_depth",
                    "id": "#main/normal_verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#main/normal_alignment_and_qc/verify_bam_id_metrics",
                    "id": "#main/normal_verify_bam_id_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/pindel_filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/pindel_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/pindel_unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/pindel_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/strelka_filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/strelka_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/strelka_unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/strelka_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/tumor_alignment_and_qc/alignment_summary_metrics",
                    "id": "#main/tumor_alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/tumor_bam_readcount_tsv",
                    "id": "#main/tumor_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/tumor_alignment_and_qc/cram",
                    "id": "#main/tumor_cram"
                },
                {
                    "type": "File",
                    "outputSource": "#main/tumor_alignment_and_qc/flagstats",
                    "id": "#main/tumor_flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#main/tumor_alignment_and_qc/hs_metrics",
                    "id": "#main/tumor_hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/tumor_alignment_and_qc/insert_size_metrics",
                    "id": "#main/tumor_insert_size_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/tumor_alignment_and_qc/mark_duplicates_metrics",
                    "id": "#main/tumor_mark_duplicates_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/tumor_alignment_and_qc/per_base_coverage_metrics",
                    "id": "#main/tumor_per_base_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/tumor_alignment_and_qc/per_base_hs_metrics",
                    "id": "#main/tumor_per_base_hs_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/tumor_alignment_and_qc/per_target_coverage_metrics",
                    "id": "#main/tumor_per_target_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/tumor_alignment_and_qc/per_target_hs_metrics",
                    "id": "#main/tumor_per_target_hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/tumor_alignment_and_qc/verify_bam_id_depth",
                    "id": "#main/tumor_verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#main/tumor_alignment_and_qc/verify_bam_id_metrics",
                    "id": "#main/tumor_verify_bam_id_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/varscan_filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/varscan_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/varscan_unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/varscan_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/vep_summary",
                    "id": "#main/vep_summary"
                }
            ],
            "steps": [
                {
                    "run": "#detect_variants.cwl",
                    "in": [
                        {
                            "source": "#main/annotate_coding_only",
                            "id": "#main/detect_variants/annotate_coding_only"
                        },
                        {
                            "source": "#main/cle_vcf_filter",
                            "id": "#main/detect_variants/cle_vcf_filter"
                        },
                        {
                            "source": "#main/cosmic_vcf",
                            "id": "#main/detect_variants/cosmic_vcf"
                        },
                        {
                            "source": "#main/custom_gnomad_vcf",
                            "id": "#main/detect_variants/custom_gnomad_vcf"
                        },
                        {
                            "source": "#main/dbsnp_vcf",
                            "id": "#main/detect_variants/dbsnp_vcf"
                        },
                        {
                            "source": "#main/docm_vcf",
                            "id": "#main/detect_variants/docm_vcf"
                        },
                        {
                            "source": "#main/hgvs_annotation",
                            "id": "#main/detect_variants/hgvs_annotation"
                        },
                        {
                            "source": "#main/interval_list",
                            "id": "#main/detect_variants/interval_list"
                        },
                        {
                            "source": "#main/mutect_artifact_detection_mode",
                            "id": "#main/detect_variants/mutect_artifact_detection_mode"
                        },
                        {
                            "source": "#main/mutect_max_alt_allele_in_normal_fraction",
                            "id": "#main/detect_variants/mutect_max_alt_allele_in_normal_fraction"
                        },
                        {
                            "source": "#main/mutect_max_alt_alleles_in_normal_count",
                            "id": "#main/detect_variants/mutect_max_alt_alleles_in_normal_count"
                        },
                        {
                            "source": "#main/mutect_scatter_count",
                            "id": "#main/detect_variants/mutect_scatter_count"
                        },
                        {
                            "source": "#main/normal_alignment_and_qc/cram",
                            "id": "#main/detect_variants/normal_cram"
                        },
                        {
                            "source": "#main/panel_of_normals_vcf",
                            "id": "#main/detect_variants/panel_of_normals_vcf"
                        },
                        {
                            "source": "#main/pindel_insert_size",
                            "id": "#main/detect_variants/pindel_insert_size"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/detect_variants/reference"
                        },
                        {
                            "source": "#main/strelka_cpu_reserved",
                            "id": "#main/detect_variants/strelka_cpu_reserved"
                        },
                        {
                            "default": true,
                            "id": "#main/detect_variants/strelka_exome_mode"
                        },
                        {
                            "source": "#main/synonyms_file",
                            "id": "#main/detect_variants/synonyms_file"
                        },
                        {
                            "source": "#main/tumor_alignment_and_qc/cram",
                            "id": "#main/detect_variants/tumor_cram"
                        },
                        {
                            "source": "#main/variants_to_table_fields",
                            "id": "#main/detect_variants/variants_to_table_fields"
                        },
                        {
                            "source": "#main/variants_to_table_genotype_fields",
                            "id": "#main/detect_variants/variants_to_table_genotype_fields"
                        },
                        {
                            "source": "#main/varscan_max_normal_freq",
                            "id": "#main/detect_variants/varscan_max_normal_freq"
                        },
                        {
                            "source": "#main/varscan_min_coverage",
                            "id": "#main/detect_variants/varscan_min_coverage"
                        },
                        {
                            "source": "#main/varscan_min_var_freq",
                            "id": "#main/detect_variants/varscan_min_var_freq"
                        },
                        {
                            "source": "#main/varscan_p_value",
                            "id": "#main/detect_variants/varscan_p_value"
                        },
                        {
                            "source": "#main/varscan_strand_filter",
                            "id": "#main/detect_variants/varscan_strand_filter"
                        },
                        {
                            "source": "#main/vep_cache_dir",
                            "id": "#main/detect_variants/vep_cache_dir"
                        },
                        {
                            "source": "#main/vep_to_table_fields",
                            "id": "#main/detect_variants/vep_to_table_fields"
                        }
                    ],
                    "out": [
                        "#main/detect_variants/mutect_unfiltered_vcf",
                        "#main/detect_variants/mutect_filtered_vcf",
                        "#main/detect_variants/strelka_unfiltered_vcf",
                        "#main/detect_variants/strelka_filtered_vcf",
                        "#main/detect_variants/varscan_unfiltered_vcf",
                        "#main/detect_variants/varscan_filtered_vcf",
                        "#main/detect_variants/pindel_unfiltered_vcf",
                        "#main/detect_variants/pindel_filtered_vcf",
                        "#main/detect_variants/docm_unfiltered_vcf",
                        "#main/detect_variants/docm_filtered_vcf",
                        "#main/detect_variants/final_vcf",
                        "#main/detect_variants/final_filtered_vcf",
                        "#main/detect_variants/final_tsv",
                        "#main/detect_variants/vep_summary",
                        "#main/detect_variants/tumor_bam_readcount_tsv",
                        "#main/detect_variants/normal_bam_readcount_tsv"
                    ],
                    "id": "#main/detect_variants"
                },
                {
                    "run": "#exome_alignment.cwl",
                    "in": [
                        {
                            "source": "#main/bait_intervals",
                            "id": "#main/normal_alignment_and_qc/bait_intervals"
                        },
                        {
                            "source": "#main/normal_bams",
                            "id": "#main/normal_alignment_and_qc/bams"
                        },
                        {
                            "source": "#main/bqsr_intervals",
                            "id": "#main/normal_alignment_and_qc/bqsr_intervals"
                        },
                        {
                            "source": "#main/dbsnp_vcf",
                            "id": "#main/normal_alignment_and_qc/dbsnp_vcf"
                        },
                        {
                            "source": "#main/known_indels",
                            "id": "#main/normal_alignment_and_qc/known_indels"
                        },
                        {
                            "source": "#main/mills",
                            "id": "#main/normal_alignment_and_qc/mills"
                        },
                        {
                            "source": "#main/qc_minimum_base_quality",
                            "id": "#main/normal_alignment_and_qc/minimum_base_quality"
                        },
                        {
                            "source": "#main/qc_minimum_mapping_quality",
                            "id": "#main/normal_alignment_and_qc/minimum_mapping_quality"
                        },
                        {
                            "source": "#main/omni_vcf",
                            "id": "#main/normal_alignment_and_qc/omni_vcf"
                        },
                        {
                            "source": "#main/per_base_bait_intervals",
                            "id": "#main/normal_alignment_and_qc/per_base_bait_intervals"
                        },
                        {
                            "source": "#main/per_base_intervals",
                            "id": "#main/normal_alignment_and_qc/per_base_intervals"
                        },
                        {
                            "source": "#main/per_target_bait_intervals",
                            "id": "#main/normal_alignment_and_qc/per_target_bait_intervals"
                        },
                        {
                            "source": "#main/per_target_intervals",
                            "id": "#main/normal_alignment_and_qc/per_target_intervals"
                        },
                        {
                            "source": "#main/picard_metric_accumulation_level",
                            "id": "#main/normal_alignment_and_qc/picard_metric_accumulation_level"
                        },
                        {
                            "source": "#main/normal_readgroups",
                            "id": "#main/normal_alignment_and_qc/readgroups"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/normal_alignment_and_qc/reference"
                        },
                        {
                            "source": "#main/target_intervals",
                            "id": "#main/normal_alignment_and_qc/target_intervals"
                        }
                    ],
                    "out": [
                        "#main/normal_alignment_and_qc/cram",
                        "#main/normal_alignment_and_qc/mark_duplicates_metrics",
                        "#main/normal_alignment_and_qc/insert_size_metrics",
                        "#main/normal_alignment_and_qc/alignment_summary_metrics",
                        "#main/normal_alignment_and_qc/hs_metrics",
                        "#main/normal_alignment_and_qc/per_target_coverage_metrics",
                        "#main/normal_alignment_and_qc/per_target_hs_metrics",
                        "#main/normal_alignment_and_qc/per_base_coverage_metrics",
                        "#main/normal_alignment_and_qc/per_base_hs_metrics",
                        "#main/normal_alignment_and_qc/flagstats",
                        "#main/normal_alignment_and_qc/verify_bam_id_metrics",
                        "#main/normal_alignment_and_qc/verify_bam_id_depth"
                    ],
                    "id": "#main/normal_alignment_and_qc"
                },
                {
                    "run": "#exome_alignment.cwl",
                    "in": [
                        {
                            "source": "#main/bait_intervals",
                            "id": "#main/tumor_alignment_and_qc/bait_intervals"
                        },
                        {
                            "source": "#main/tumor_bams",
                            "id": "#main/tumor_alignment_and_qc/bams"
                        },
                        {
                            "source": "#main/bqsr_intervals",
                            "id": "#main/tumor_alignment_and_qc/bqsr_intervals"
                        },
                        {
                            "source": "#main/dbsnp_vcf",
                            "id": "#main/tumor_alignment_and_qc/dbsnp_vcf"
                        },
                        {
                            "source": "#main/known_indels",
                            "id": "#main/tumor_alignment_and_qc/known_indels"
                        },
                        {
                            "source": "#main/mills",
                            "id": "#main/tumor_alignment_and_qc/mills"
                        },
                        {
                            "source": "#main/qc_minimum_base_quality",
                            "id": "#main/tumor_alignment_and_qc/minimum_base_quality"
                        },
                        {
                            "source": "#main/qc_minimum_mapping_quality",
                            "id": "#main/tumor_alignment_and_qc/minimum_mapping_quality"
                        },
                        {
                            "source": "#main/omni_vcf",
                            "id": "#main/tumor_alignment_and_qc/omni_vcf"
                        },
                        {
                            "source": "#main/per_base_bait_intervals",
                            "id": "#main/tumor_alignment_and_qc/per_base_bait_intervals"
                        },
                        {
                            "source": "#main/per_base_intervals",
                            "id": "#main/tumor_alignment_and_qc/per_base_intervals"
                        },
                        {
                            "source": "#main/per_target_bait_intervals",
                            "id": "#main/tumor_alignment_and_qc/per_target_bait_intervals"
                        },
                        {
                            "source": "#main/per_target_intervals",
                            "id": "#main/tumor_alignment_and_qc/per_target_intervals"
                        },
                        {
                            "source": "#main/picard_metric_accumulation_level",
                            "id": "#main/tumor_alignment_and_qc/picard_metric_accumulation_level"
                        },
                        {
                            "source": "#main/tumor_readgroups",
                            "id": "#main/tumor_alignment_and_qc/readgroups"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/tumor_alignment_and_qc/reference"
                        },
                        {
                            "source": "#main/target_intervals",
                            "id": "#main/tumor_alignment_and_qc/target_intervals"
                        }
                    ],
                    "out": [
                        "#main/tumor_alignment_and_qc/cram",
                        "#main/tumor_alignment_and_qc/mark_duplicates_metrics",
                        "#main/tumor_alignment_and_qc/insert_size_metrics",
                        "#main/tumor_alignment_and_qc/alignment_summary_metrics",
                        "#main/tumor_alignment_and_qc/hs_metrics",
                        "#main/tumor_alignment_and_qc/per_target_coverage_metrics",
                        "#main/tumor_alignment_and_qc/per_target_hs_metrics",
                        "#main/tumor_alignment_and_qc/per_base_coverage_metrics",
                        "#main/tumor_alignment_and_qc/per_base_hs_metrics",
                        "#main/tumor_alignment_and_qc/flagstats",
                        "#main/tumor_alignment_and_qc/verify_bam_id_metrics",
                        "#main/tumor_alignment_and_qc/verify_bam_id_depth"
                    ],
                    "id": "#main/tumor_alignment_and_qc"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "add GT tags",
            "arguments": [
                "/usr/bin/perl",
                "/usr/bin/add_strelka_gt.pl",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)"
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#add_gt.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "add_gt.vcf"
                    },
                    "id": "#add_gt.cwl/processed_vcf"
                }
            ],
            "id": "#add_gt.cwl"
        },
        {
            "class": "Workflow",
            "label": "process VCF workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#process_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#process_vcf.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#process_vcf.cwl/processed_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#add_gt.cwl",
                    "in": [
                        {
                            "source": "#process_vcf.cwl/vcf",
                            "id": "#process_vcf.cwl/add_gt/vcf"
                        }
                    ],
                    "out": [
                        "#process_vcf.cwl/add_gt/processed_vcf"
                    ],
                    "id": "#process_vcf.cwl/add_gt"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#process_vcf.cwl/add_gt/processed_vcf",
                            "id": "#process_vcf.cwl/bgzip/file"
                        }
                    ],
                    "out": [
                        "#process_vcf.cwl/bgzip/bgzipped_file"
                    ],
                    "id": "#process_vcf.cwl/bgzip"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#process_vcf.cwl/bgzip/bgzipped_file",
                            "id": "#process_vcf.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#process_vcf.cwl/index/indexed_vcf"
                    ],
                    "id": "#process_vcf.cwl/index"
                }
            ],
            "id": "#process_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "strelka 2.7.1",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/strelka_helper.pl"
            ],
            "requirements": [
                {
                    "coresMin": 4,
                    "ramMin": 4000,
                    "class": "ResourceRequirement"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.cpu_reserved)",
                    "position": 1
                },
                {
                    "valueFrom": "$(runtime.outdir)",
                    "position": 2
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#strelka.cwl/cpu_reserved"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--exome",
                        "position": 6
                    },
                    "id": "#strelka.cwl/exome_mode"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--normalBam=",
                        "separate": false,
                        "position": 4
                    },
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#strelka.cwl/normal_cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--referenceFasta=",
                        "separate": false,
                        "position": 5
                    },
                    "id": "#strelka.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--tumorBam=",
                        "separate": false,
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#strelka.cwl/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "results/variants/somatic.indels.vcf.gz"
                    },
                    "id": "#strelka.cwl/indels"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "results/variants/somatic.snvs.vcf.gz"
                    },
                    "id": "#strelka.cwl/snvs"
                }
            ],
            "id": "#strelka.cwl"
        },
        {
            "class": "Workflow",
            "label": "strelka workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#workflow.cwl_6/cpu_reserved"
                },
                {
                    "type": "boolean",
                    "id": "#workflow.cwl_6/exome_mode"
                },
                {
                    "type": "File",
                    "id": "#workflow.cwl_6/interval_list"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_6/normal_cram"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_6/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_6/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_6/filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_6/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_6/filter/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_6/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#workflow.cwl_3",
                    "in": [
                        {
                            "source": "#workflow.cwl_6/tumor_cram",
                            "id": "#workflow.cwl_6/filter/cram"
                        },
                        {
                            "source": "#workflow.cwl_6/reference",
                            "id": "#workflow.cwl_6/filter/reference"
                        },
                        {
                            "valueFrom": "strelka",
                            "id": "#workflow.cwl_6/filter/variant_caller"
                        },
                        {
                            "source": "#workflow.cwl_6/region_filter/filtered_vcf",
                            "id": "#workflow.cwl_6/filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_6/filter/unfiltered_vcf",
                        "#workflow.cwl_6/filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_6/filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_6/merge/merged_vcf",
                            "id": "#workflow.cwl_6/index_full/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_6/index_full/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_6/index_full"
                },
                {
                    "run": "#merge.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_6/process/processed_vcf",
                            "id": "#workflow.cwl_6/merge/vcfs"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_6/merge/merged_vcf"
                    ],
                    "id": "#workflow.cwl_6/merge"
                },
                {
                    "scatter": "#workflow.cwl_6/process/vcf",
                    "run": "#process_vcf.cwl",
                    "in": [
                        {
                            "source": [
                                "#workflow.cwl_6/strelka/snvs",
                                "#workflow.cwl_6/strelka/indels"
                            ],
                            "id": "#workflow.cwl_6/process/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_6/process/processed_vcf"
                    ],
                    "id": "#workflow.cwl_6/process"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_6/interval_list",
                            "id": "#workflow.cwl_6/region_filter/interval_list"
                        },
                        {
                            "source": "#workflow.cwl_6/reference",
                            "id": "#workflow.cwl_6/region_filter/reference"
                        },
                        {
                            "source": "#workflow.cwl_6/index_full/indexed_vcf",
                            "id": "#workflow.cwl_6/region_filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_6/region_filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_6/region_filter"
                },
                {
                    "run": "#strelka.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_6/cpu_reserved",
                            "id": "#workflow.cwl_6/strelka/cpu_reserved"
                        },
                        {
                            "source": "#workflow.cwl_6/exome_mode",
                            "id": "#workflow.cwl_6/strelka/exome_mode"
                        },
                        {
                            "source": "#workflow.cwl_6/normal_cram",
                            "id": "#workflow.cwl_6/strelka/normal_cram"
                        },
                        {
                            "source": "#workflow.cwl_6/reference",
                            "id": "#workflow.cwl_6/strelka/reference"
                        },
                        {
                            "source": "#workflow.cwl_6/tumor_cram",
                            "id": "#workflow.cwl_6/strelka/tumor_cram"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_6/strelka/indels",
                        "#workflow.cwl_6/strelka/snvs"
                    ],
                    "id": "#workflow.cwl_6/strelka"
                }
            ],
            "id": "#workflow.cwl_6"
        },
        {
            "class": "Workflow",
            "label": "Unaligned to aligned BAM",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#align.cwl/bam"
                },
                {
                    "type": "string",
                    "id": "#align.cwl/readgroup"
                },
                {
                    "type": "string",
                    "id": "#align.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#align.cwl/align_and_tag/aligned_bam",
                    "id": "#align.cwl/tagged_bam"
                }
            ],
            "steps": [
                {
                    "run": "#align_and_tag.cwl",
                    "in": [
                        {
                            "source": "#align.cwl/bam",
                            "id": "#align.cwl/align_and_tag/bam"
                        },
                        {
                            "source": "#align.cwl/readgroup",
                            "id": "#align.cwl/align_and_tag/readgroup"
                        },
                        {
                            "source": "#align.cwl/reference",
                            "id": "#align.cwl/align_and_tag/reference"
                        }
                    ],
                    "out": [
                        "#align.cwl/align_and_tag/aligned_bam"
                    ],
                    "id": "#align.cwl/align_and_tag"
                }
            ],
            "id": "#align.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "align with bwa_mem and tag",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/alignment_helper.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 20000
                }
            ],
            "stdout": "refAlign.bam",
            "arguments": [
                {
                    "position": 4,
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#align_and_tag.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#align_and_tag.cwl/readgroup"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#align_and_tag.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#align_and_tag.cwl/aligned_bam",
                    "outputBinding": {
                        "glob": "refAlign.bam"
                    }
                }
            ],
            "id": "#align_and_tag.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "apply BQSR",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "PrintReads"
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/Final.bam"
                },
                "-preserveQ",
                "6",
                "-SQQ",
                "10",
                "-SQQ",
                "20",
                "-SQQ",
                "30",
                "-nct",
                "8",
                "--disable_indel_quals"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#apply_bqsr.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-BQSR",
                        "position": 3
                    },
                    "id": "#apply_bqsr.cwl/bqsr_table"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#apply_bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "Final.bam"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#apply_bqsr.cwl/bqsr_bam"
                }
            ],
            "id": "#apply_bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "BAM to CRAM conversion",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "view",
                "-C"
            ],
            "stdout": "final.cram",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bam_to_cram.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#bam_to_cram.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bam_to_cram.cwl/cram",
                    "outputBinding": {
                        "glob": "final.cram"
                    }
                }
            ],
            "id": "#bam_to_cram.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "create BQSR table",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "BaseRecalibrator"
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/bqsr.table"
                },
                "--preserve_qscores_less_than",
                "6",
                "--disable_auto_index_creation_and_locking_when_reading_rods",
                "--disable_bam_indexing",
                "-dfrac",
                ".1",
                "-nct",
                "4"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bqsr.cwl/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-L"
                        }
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "default": [
                        "chr1",
                        "chr2",
                        "chr3",
                        "chr4",
                        "chr5",
                        "chr6",
                        "chr7",
                        "chr8",
                        "chr9",
                        "chr10",
                        "chr11",
                        "chr12",
                        "chr13",
                        "chr14",
                        "chr15",
                        "chr16",
                        "chr17",
                        "chr18",
                        "chr19",
                        "chr20",
                        "chr21",
                        "chr22"
                    ],
                    "id": "#bqsr.cwl/intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-knownSites",
                            "position": 4
                        }
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bqsr.cwl/known_sites"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 2
                    },
                    "id": "#bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "bqsr.table"
                    },
                    "id": "#bqsr.cwl/bqsr_table"
                }
            ],
            "id": "#bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index cram",
            "arguments": [
                "cp",
                "$(inputs.cram.path)",
                "$(runtime.outdir)/$(inputs.cram.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/opt/samtools/bin/samtools",
                "index",
                "$(runtime.outdir)/$(inputs.cram.basename)",
                "$(runtime.outdir)/$(inputs.cram.basename).crai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "ln",
                "-s",
                "$(inputs.cram.basename).crai",
                "$(runtime.outdir)/$(inputs.cram.nameroot).crai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_cram.cwl/cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.cram.basename)"
                    },
                    "id": "#index_cram.cwl/indexed_cram"
                }
            ],
            "id": "#index_cram.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "mark duplicates and sort",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/markduplicates_helper.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 40000
                }
            ],
            "arguments": [
                {
                    "position": 2,
                    "valueFrom": "$(runtime.cores)"
                },
                {
                    "position": 3,
                    "valueFrom": "$(runtime.outdir)/MarkedSorted.bam"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#mark_duplicates_and_sort.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mark_dups_metrics.txt"
                    },
                    "id": "#mark_duplicates_and_sort.cwl/metrics_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "MarkedSorted.bam"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#mark_duplicates_and_sort.cwl/sorted_bam"
                }
            ],
            "id": "#mark_duplicates_and_sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "merge BAMs",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "merge"
            ],
            "arguments": [
                "AlignedMerged.bam"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#merge.cwl_2/bams"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "AlignedMerged.bam"
                    },
                    "id": "#merge.cwl_2/merged_bam"
                }
            ],
            "id": "#merge.cwl_2"
        },
        {
            "class": "CommandLineTool",
            "label": "sort BAM by name",
            "baseCommand": [
                "/usr/bin/sambamba",
                "sort"
            ],
            "arguments": [
                "-t",
                {
                    "valueFrom": "$(runtime.cores)"
                },
                "-m",
                "12G",
                "-n",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/NameSorted.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 13000,
                    "coresMin": 8
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#name_sort.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "NameSorted.bam"
                    },
                    "id": "#name_sort.cwl/name_sorted_bam"
                }
            ],
            "id": "#name_sort.cwl"
        },
        {
            "class": "Workflow",
            "label": "Unaligned BAM to BQSR and VCF",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#workflow.cwl_7/bams"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#workflow.cwl_7/bqsr_intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_7/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_7/known_indels"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_7/mills"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#workflow.cwl_7/readgroups"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_7/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_7/index_cram/indexed_cram",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_7/final_cram"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_7/mark_duplicates_and_sort/metrics_file",
                    "id": "#workflow.cwl_7/mark_duplicates_metrics_file"
                }
            ],
            "steps": [
                {
                    "scatter": [
                        "#workflow.cwl_7/align/bam",
                        "#workflow.cwl_7/align/readgroup"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#align.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/bams",
                            "id": "#workflow.cwl_7/align/bam"
                        },
                        {
                            "source": "#workflow.cwl_7/readgroups",
                            "id": "#workflow.cwl_7/align/readgroup"
                        },
                        {
                            "source": "#workflow.cwl_7/reference",
                            "id": "#workflow.cwl_7/align/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/align/tagged_bam"
                    ],
                    "id": "#workflow.cwl_7/align"
                },
                {
                    "run": "#apply_bqsr.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/mark_duplicates_and_sort/sorted_bam",
                            "id": "#workflow.cwl_7/apply_bqsr/bam"
                        },
                        {
                            "source": "#workflow.cwl_7/bqsr/bqsr_table",
                            "id": "#workflow.cwl_7/apply_bqsr/bqsr_table"
                        },
                        {
                            "source": "#workflow.cwl_7/reference",
                            "id": "#workflow.cwl_7/apply_bqsr/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/apply_bqsr/bqsr_bam"
                    ],
                    "id": "#workflow.cwl_7/apply_bqsr"
                },
                {
                    "run": "#bam_to_cram.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/apply_bqsr/bqsr_bam",
                            "id": "#workflow.cwl_7/bam_to_cram/bam"
                        },
                        {
                            "source": "#workflow.cwl_7/reference",
                            "id": "#workflow.cwl_7/bam_to_cram/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/bam_to_cram/cram"
                    ],
                    "id": "#workflow.cwl_7/bam_to_cram"
                },
                {
                    "run": "#bqsr.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/mark_duplicates_and_sort/sorted_bam",
                            "id": "#workflow.cwl_7/bqsr/bam"
                        },
                        {
                            "source": "#workflow.cwl_7/bqsr_intervals",
                            "id": "#workflow.cwl_7/bqsr/intervals"
                        },
                        {
                            "source": [
                                "#workflow.cwl_7/dbsnp_vcf",
                                "#workflow.cwl_7/mills",
                                "#workflow.cwl_7/known_indels"
                            ],
                            "id": "#workflow.cwl_7/bqsr/known_sites"
                        },
                        {
                            "source": "#workflow.cwl_7/reference",
                            "id": "#workflow.cwl_7/bqsr/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/bqsr/bqsr_table"
                    ],
                    "id": "#workflow.cwl_7/bqsr"
                },
                {
                    "run": "#index_cram.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/bam_to_cram/cram",
                            "id": "#workflow.cwl_7/index_cram/cram"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/index_cram/indexed_cram"
                    ],
                    "id": "#workflow.cwl_7/index_cram"
                },
                {
                    "run": "#mark_duplicates_and_sort.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/name_sort/name_sorted_bam",
                            "id": "#workflow.cwl_7/mark_duplicates_and_sort/bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/mark_duplicates_and_sort/sorted_bam",
                        "#workflow.cwl_7/mark_duplicates_and_sort/metrics_file"
                    ],
                    "id": "#workflow.cwl_7/mark_duplicates_and_sort"
                },
                {
                    "run": "#merge.cwl_2",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/align/tagged_bam",
                            "id": "#workflow.cwl_7/merge/bams"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/merge/merged_bam"
                    ],
                    "id": "#workflow.cwl_7/merge"
                },
                {
                    "run": "#name_sort.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/merge/merged_bam",
                            "id": "#workflow.cwl_7/name_sort/bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/name_sort/name_sorted_bam"
                    ],
                    "id": "#workflow.cwl_7/name_sort"
                }
            ],
            "id": "#workflow.cwl_7"
        },
        {
            "class": "Workflow",
            "label": "bgzip and index VCF",
            "inputs": [
                {
                    "type": "File",
                    "id": "#bgzip_and_index.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#bgzip_and_index.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bgzip_and_index.cwl/indexed_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#bgzip_and_index.cwl/vcf",
                            "id": "#bgzip_and_index.cwl/bgzip/file"
                        }
                    ],
                    "out": [
                        "#bgzip_and_index.cwl/bgzip/bgzipped_file"
                    ],
                    "id": "#bgzip_and_index.cwl/bgzip"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#bgzip_and_index.cwl/bgzip/bgzipped_file",
                            "id": "#bgzip_and_index.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#bgzip_and_index.cwl/index/indexed_vcf"
                    ],
                    "id": "#bgzip_and_index.cwl/index"
                }
            ],
            "id": "#bgzip_and_index.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/intervals_to_bed.pl"
            ],
            "stdout": "interval_list.bed",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#intervals_to_bed.cwl/interval_list"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#intervals_to_bed.cwl/interval_bed",
                    "outputBinding": {
                        "glob": "interval_list.bed"
                    }
                }
            ],
            "id": "#intervals_to_bed.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "create filtered VCF",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "VariantFiltration"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "--maskName",
                "processSomatic",
                "--filterNotInMask",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/output.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--mask",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#set_filter_status.cwl/filtered_vcf"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#set_filter_status.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#set_filter_status.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.vcf.gz"
                    },
                    "id": "#set_filter_status.cwl/merged_vcf"
                }
            ],
            "id": "#set_filter_status.cwl"
        },
        {
            "class": "Workflow",
            "label": "varscan somatic workflow",
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#varscan.cwl/max_normal_freq"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#varscan.cwl/min_coverage"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#varscan.cwl/min_var_freq"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#varscan.cwl/normal_cram"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#varscan.cwl/p_value"
                },
                {
                    "type": "string",
                    "id": "#varscan.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#varscan.cwl/roi_bed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#varscan.cwl/strand_filter"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#varscan.cwl/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_indels/germline_hc",
                    "id": "#varscan.cwl/germline_hc_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_snvs/germline_hc",
                    "id": "#varscan.cwl/germline_hc_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_indels/germline",
                    "id": "#varscan.cwl/germline_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_snvs/germline",
                    "id": "#varscan.cwl/germline_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/somatic/indels",
                    "id": "#varscan.cwl/indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_indels/loh_hc",
                    "id": "#varscan.cwl/loh_hc_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_snvs/loh_hc",
                    "id": "#varscan.cwl/loh_hc_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_indels/loh",
                    "id": "#varscan.cwl/loh_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_snvs/loh",
                    "id": "#varscan.cwl/loh_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/somatic/snvs",
                    "id": "#varscan.cwl/snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_indels/somatic_hc",
                    "id": "#varscan.cwl/somatic_hc_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_snvs/somatic_hc",
                    "id": "#varscan.cwl/somatic_hc_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_indels/somatic",
                    "id": "#varscan.cwl/somatic_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_snvs/somatic",
                    "id": "#varscan.cwl/somatic_snvs"
                }
            ],
            "steps": [
                {
                    "run": "#varscan_processsomatic.cwl",
                    "in": [
                        {
                            "source": "#varscan.cwl/max_normal_freq",
                            "id": "#varscan.cwl/process_somatic_indels/max_normal_freq"
                        },
                        {
                            "source": "#varscan.cwl/somatic/indels",
                            "id": "#varscan.cwl/process_somatic_indels/variants"
                        }
                    ],
                    "out": [
                        "#varscan.cwl/process_somatic_indels/somatic_hc",
                        "#varscan.cwl/process_somatic_indels/somatic",
                        "#varscan.cwl/process_somatic_indels/germline_hc",
                        "#varscan.cwl/process_somatic_indels/germline",
                        "#varscan.cwl/process_somatic_indels/loh_hc",
                        "#varscan.cwl/process_somatic_indels/loh"
                    ],
                    "id": "#varscan.cwl/process_somatic_indels"
                },
                {
                    "run": "#varscan_processsomatic.cwl",
                    "in": [
                        {
                            "source": "#varscan.cwl/max_normal_freq",
                            "id": "#varscan.cwl/process_somatic_snvs/max_normal_freq"
                        },
                        {
                            "source": "#varscan.cwl/somatic/snvs",
                            "id": "#varscan.cwl/process_somatic_snvs/variants"
                        }
                    ],
                    "out": [
                        "#varscan.cwl/process_somatic_snvs/somatic_hc",
                        "#varscan.cwl/process_somatic_snvs/somatic",
                        "#varscan.cwl/process_somatic_snvs/germline_hc",
                        "#varscan.cwl/process_somatic_snvs/germline",
                        "#varscan.cwl/process_somatic_snvs/loh_hc",
                        "#varscan.cwl/process_somatic_snvs/loh"
                    ],
                    "id": "#varscan.cwl/process_somatic_snvs"
                },
                {
                    "run": "#varscan_somatic.cwl",
                    "in": [
                        {
                            "source": "#varscan.cwl/min_coverage",
                            "id": "#varscan.cwl/somatic/min_coverage"
                        },
                        {
                            "source": "#varscan.cwl/min_var_freq",
                            "id": "#varscan.cwl/somatic/min_var_freq"
                        },
                        {
                            "source": "#varscan.cwl/normal_cram",
                            "id": "#varscan.cwl/somatic/normal_cram"
                        },
                        {
                            "source": "#varscan.cwl/p_value",
                            "id": "#varscan.cwl/somatic/p_value"
                        },
                        {
                            "source": "#varscan.cwl/reference",
                            "id": "#varscan.cwl/somatic/reference"
                        },
                        {
                            "source": "#varscan.cwl/roi_bed",
                            "id": "#varscan.cwl/somatic/roi_bed"
                        },
                        {
                            "source": "#varscan.cwl/strand_filter",
                            "id": "#varscan.cwl/somatic/strand_filter"
                        },
                        {
                            "source": "#varscan.cwl/tumor_cram",
                            "id": "#varscan.cwl/somatic/tumor_cram"
                        }
                    ],
                    "out": [
                        "#varscan.cwl/somatic/snvs",
                        "#varscan.cwl/somatic/indels"
                    ],
                    "id": "#varscan.cwl/somatic"
                }
            ],
            "id": "#varscan.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "varscan v2.4.2 processSomatic",
            "arguments": [
                "cp",
                "$(inputs.variants.path)",
                "$(runtime.outdir)/$(inputs.variants.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "java",
                "-jar",
                "/opt/varscan/VarScan.jar",
                "processSomatic"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--max-normal-freq",
                        "position": 2
                    },
                    "id": "#varscan_processsomatic.cwl/max_normal_freq"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(runtime.outdir)/$(self.basename)",
                        "position": 1
                    },
                    "id": "#varscan_processsomatic.cwl/variants"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.Germline.vcf"
                    },
                    "id": "#varscan_processsomatic.cwl/germline"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.Germline.hc.vcf"
                    },
                    "id": "#varscan_processsomatic.cwl/germline_hc"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.LOH.vcf"
                    },
                    "id": "#varscan_processsomatic.cwl/loh"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.LOH.hc.vcf"
                    },
                    "id": "#varscan_processsomatic.cwl/loh_hc"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.Somatic.vcf"
                    },
                    "id": "#varscan_processsomatic.cwl/somatic"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.Somatic.hc.vcf"
                    },
                    "id": "#varscan_processsomatic.cwl/somatic_hc"
                }
            ],
            "id": "#varscan_processsomatic.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "varscan v2.4.2 somatic",
            "baseCommand": "/usr/bin/varscan_helper.sh",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 12000
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#varscan_somatic.cwl/min_coverage"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "inputBinding": {
                        "position": 6
                    },
                    "id": "#varscan_somatic.cwl/min_var_freq"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#varscan_somatic.cwl/normal_cram"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "inputBinding": {
                        "position": 7
                    },
                    "id": "#varscan_somatic.cwl/p_value"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#varscan_somatic.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 8
                    },
                    "id": "#varscan_somatic.cwl/roi_bed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#varscan_somatic.cwl/strand_filter"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#varscan_somatic.cwl/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.indel.vcf"
                    },
                    "id": "#varscan_somatic.cwl/indels"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.snp.vcf"
                    },
                    "id": "#varscan_somatic.cwl/snvs"
                }
            ],
            "id": "#varscan_somatic.cwl"
        },
        {
            "class": "Workflow",
            "label": "Varscan Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#workflow.cwl_8/interval_list"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#workflow.cwl_8/max_normal_freq"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#workflow.cwl_8/min_coverage"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "id": "#workflow.cwl_8/min_var_freq"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_8/normal_cram"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "id": "#workflow.cwl_8/p_value"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_8/reference"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "id": "#workflow.cwl_8/strand_filter"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_8/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_8/filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_8/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_8/filter/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_8/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_8/varscan/somatic_hc_indels",
                            "id": "#workflow.cwl_8/bgzip_and_index_hc_indels/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_8/bgzip_and_index_hc_indels/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_8/bgzip_and_index_hc_indels"
                },
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_8/varscan/somatic_hc_snvs",
                            "id": "#workflow.cwl_8/bgzip_and_index_hc_snvs/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_8/bgzip_and_index_hc_snvs/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_8/bgzip_and_index_hc_snvs"
                },
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_8/varscan/somatic_indels",
                            "id": "#workflow.cwl_8/bgzip_and_index_indels/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_8/bgzip_and_index_indels/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_8/bgzip_and_index_indels"
                },
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_8/varscan/somatic_snvs",
                            "id": "#workflow.cwl_8/bgzip_and_index_snvs/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_8/bgzip_and_index_snvs/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_8/bgzip_and_index_snvs"
                },
                {
                    "run": "#workflow.cwl_3",
                    "in": [
                        {
                            "source": "#workflow.cwl_8/tumor_cram",
                            "id": "#workflow.cwl_8/filter/cram"
                        },
                        {
                            "source": "#workflow.cwl_8/min_var_freq",
                            "id": "#workflow.cwl_8/filter/min_var_freq"
                        },
                        {
                            "source": "#workflow.cwl_8/reference",
                            "id": "#workflow.cwl_8/filter/reference"
                        },
                        {
                            "valueFrom": "varscan",
                            "id": "#workflow.cwl_8/filter/variant_caller"
                        },
                        {
                            "source": "#workflow.cwl_8/index/indexed_vcf",
                            "id": "#workflow.cwl_8/filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_8/filter/unfiltered_vcf",
                        "#workflow.cwl_8/filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_8/filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_8/merge/merged_vcf",
                            "id": "#workflow.cwl_8/index/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_8/index/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_8/index"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_8/merge_indels/merged_vcf",
                            "id": "#workflow.cwl_8/index_indels/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_8/index_indels/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_8/index_indels"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_8/merge_snvs/merged_vcf",
                            "id": "#workflow.cwl_8/index_snvs/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_8/index_snvs/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_8/index_snvs"
                },
                {
                    "run": "#intervals_to_bed.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_8/interval_list",
                            "id": "#workflow.cwl_8/intervals_to_bed/interval_list"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_8/intervals_to_bed/interval_bed"
                    ],
                    "id": "#workflow.cwl_8/intervals_to_bed"
                },
                {
                    "run": "#merge.cwl",
                    "in": [
                        {
                            "source": [
                                "#workflow.cwl_8/index_snvs/indexed_vcf",
                                "#workflow.cwl_8/index_indels/indexed_vcf"
                            ],
                            "id": "#workflow.cwl_8/merge/vcfs"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_8/merge/merged_vcf"
                    ],
                    "id": "#workflow.cwl_8/merge"
                },
                {
                    "run": "#set_filter_status.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_8/bgzip_and_index_hc_indels/indexed_vcf",
                            "id": "#workflow.cwl_8/merge_indels/filtered_vcf"
                        },
                        {
                            "source": "#workflow.cwl_8/reference",
                            "id": "#workflow.cwl_8/merge_indels/reference"
                        },
                        {
                            "source": "#workflow.cwl_8/bgzip_and_index_indels/indexed_vcf",
                            "id": "#workflow.cwl_8/merge_indels/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_8/merge_indels/merged_vcf"
                    ],
                    "id": "#workflow.cwl_8/merge_indels"
                },
                {
                    "run": "#set_filter_status.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_8/bgzip_and_index_hc_snvs/indexed_vcf",
                            "id": "#workflow.cwl_8/merge_snvs/filtered_vcf"
                        },
                        {
                            "source": "#workflow.cwl_8/reference",
                            "id": "#workflow.cwl_8/merge_snvs/reference"
                        },
                        {
                            "source": "#workflow.cwl_8/bgzip_and_index_snvs/indexed_vcf",
                            "id": "#workflow.cwl_8/merge_snvs/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_8/merge_snvs/merged_vcf"
                    ],
                    "id": "#workflow.cwl_8/merge_snvs"
                },
                {
                    "run": "#varscan.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_8/max_normal_freq",
                            "id": "#workflow.cwl_8/varscan/max_normal_freq"
                        },
                        {
                            "source": "#workflow.cwl_8/min_coverage",
                            "id": "#workflow.cwl_8/varscan/min_coverage"
                        },
                        {
                            "source": "#workflow.cwl_8/min_var_freq",
                            "id": "#workflow.cwl_8/varscan/min_var_freq"
                        },
                        {
                            "source": "#workflow.cwl_8/normal_cram",
                            "id": "#workflow.cwl_8/varscan/normal_cram"
                        },
                        {
                            "source": "#workflow.cwl_8/p_value",
                            "id": "#workflow.cwl_8/varscan/p_value"
                        },
                        {
                            "source": "#workflow.cwl_8/reference",
                            "id": "#workflow.cwl_8/varscan/reference"
                        },
                        {
                            "source": "#workflow.cwl_8/intervals_to_bed/interval_bed",
                            "id": "#workflow.cwl_8/varscan/roi_bed"
                        },
                        {
                            "source": "#workflow.cwl_8/strand_filter",
                            "id": "#workflow.cwl_8/varscan/strand_filter"
                        },
                        {
                            "source": "#workflow.cwl_8/tumor_cram",
                            "id": "#workflow.cwl_8/varscan/tumor_cram"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_8/varscan/somatic_snvs",
                        "#workflow.cwl_8/varscan/somatic_indels",
                        "#workflow.cwl_8/varscan/somatic_hc_snvs",
                        "#workflow.cwl_8/varscan/somatic_hc_indels"
                    ],
                    "id": "#workflow.cwl_8/varscan"
                }
            ],
            "id": "#workflow.cwl_8"
        }
    ],
    "cwlVersion": "v1.0"
}
